# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class NSB2023Well(str, Enum):
    """
    Enum class for NSB2023Well.
    """

    """
    allowed enum values
    """
    SELECT = 'Select...'
    NO_WELL = 'No Well'
    SCIENTIFICA_CAM = 'Scientifica (CAM)'
    MESOSCOPE = 'Mesoscope'
    NEUROPIXEL = 'Neuropixel'
    WHC_2_P = 'WHC 2P'
    WHC_NP = 'WHC NP'
    WHC_NP_ZIRCONIA = 'WHC NP (Zirconia)'
    AI_STRAIGHT_BAR_WELL = 'AI Straight bar well'
    LC_WELL = 'LC well'
    DHC_WELL = 'DHC well'
    MOTOR__CTX_SLAP2_WELL = 'Motor Ctx SLAP2 well'
    VISUAL__CTX_SLAP2_WELL = 'Visual Ctx SLAP2 well'
    OTHER_SEE_REQUESTOR_COMM = 'Other (See requestor comments)'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of NSB2023Well from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class LASReqpro4(str, Enum):
    """
    Enum class for ReqPro4.
    """

    """
    allowed enum values
    """
    TISSUE_COLLECTION = 'Tissue Collection'
    INDUCTION = 'Induction'
    DOSING = 'Dosing'
    RETRO_ORBITAL_INJECTION = 'Retro-Orbital Injection'
    INTRACEREBROVENTRICULAR = 'Intracerebroventricular Injection'
    BLOOD_COLLECTION = 'Blood Collection'
    CEREBROSPINAL_FLUID_COL = 'Cerebrospinal Fluid Collection (CSF)'
    OTHER = 'Other'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of LASReqpro4 from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class NSB2019HpIsoLevel(str, Enum):
    """
    Enum class for HpIsoLevel
    """

    """
    allowed enum values
    """
    N_025 = '0.25'
    N_050 = '0.50'
    N_075 = '0.75'
    N_100 = '1.00'
    N_125 = '1.25'
    N_15 = '1.5'
    N_175 = '1.75'
    N_200 = '2.00'
    N_225 = '2.25'
    N_250 = '2.50'
    N_275 = '2.75'
    N_300 = '3.00+'
    SELECT = 'Select...'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of NSB2019HpIsoLevel from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class LASTctiss(str, Enum):
    """
    Enum class for TCTiss.
    """

    """
    allowed enum values
    """
    BRAIN = 'Brain'
    RIGHT_EYE = 'Right Eye'
    LEFT_EYE = 'Left Eye'
    EARS = 'Ears'
    SPINAL_CORD = 'Spinal Cord'
    HEART = 'Heart'
    LIVER = 'Liver'
    EMBRYO_SPECIFY_BELOW = 'Embryo (Specify below)'
    LYMPH_NODES_SPECIFY_BELO = 'Lymph nodes (Specify below)'
    SPLEEN = 'Spleen'
    KIDNEYS = 'Kidneys'
    REPRODUCTIVE_ORGAN = 'Reproductive Organ'
    EPIDIDYMIS = 'Epididymis'
    TAIL_SNIPS = 'Tail Snips'
    OTHER_TISSUE_SPECIFY_BE = 'Other Tissue (Specify below)'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of LASTctiss from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from aind_sharepoint_service_async_client.models.las_bctype import LASBctype
from aind_sharepoint_service_async_client.models.las_deliverylocation import LASDeliverylocation
from aind_sharepoint_service_async_client.models.las_doseroute import LASDoseroute
from aind_sharepoint_service_async_client.models.las_icvlims import LASIcvlims
from aind_sharepoint_service_async_client.models.las_icvroute1 import LASIcvroute1
from aind_sharepoint_service_async_client.models.las_icvroute2 import LASIcvroute2
from aind_sharepoint_service_async_client.models.las_icvroute3 import LASIcvroute3
from aind_sharepoint_service_async_client.models.las_icvroute4 import LASIcvroute4
from aind_sharepoint_service_async_client.models.las_icvroute5 import LASIcvroute5
from aind_sharepoint_service_async_client.models.las_limsproject import LASLimsproject
from aind_sharepoint_service_async_client.models.las_limsworkflow import LASLimsworkflow
from aind_sharepoint_service_async_client.models.las_limsworkflow2 import LASLimsworkflow2
from aind_sharepoint_service_async_client.models.las_postfix import LASPostfix
from aind_sharepoint_service_async_client.models.las_projectid import LASProjectid
from aind_sharepoint_service_async_client.models.las_protocol import LASProtocol
from aind_sharepoint_service_async_client.models.las_reqpro1 import LASReqpro1
from aind_sharepoint_service_async_client.models.las_reqpro2 import LASReqpro2
from aind_sharepoint_service_async_client.models.las_reqpro3 import LASReqpro3
from aind_sharepoint_service_async_client.models.las_reqpro4 import LASReqpro4
from aind_sharepoint_service_async_client.models.las_requeststatus2 import LASRequeststatus2
from aind_sharepoint_service_async_client.models.las_roeye1 import LASRoeye1
from aind_sharepoint_service_async_client.models.las_roeye2 import LASRoeye2
from aind_sharepoint_service_async_client.models.las_roeye3 import LASRoeye3
from aind_sharepoint_service_async_client.models.las_roeye4 import LASRoeye4
from aind_sharepoint_service_async_client.models.las_roeye5 import LASRoeye5
from aind_sharepoint_service_async_client.models.las_rolims import LASRolims
from aind_sharepoint_service_async_client.models.las_rosop import LASRosop
from aind_sharepoint_service_async_client.models.las_rowhere import LASRowhere
from aind_sharepoint_service_async_client.models.las_species import LASSpecies
from aind_sharepoint_service_async_client.models.las_tam_frequency import LASTamFrequency
from aind_sharepoint_service_async_client.models.las_tcprep import LASTcprep
from aind_sharepoint_service_async_client.models.las_tctiss import LASTctiss
from aind_sharepoint_service_async_client.models.las_tmp_frequency import LASTmpFrequency
from aind_sharepoint_service_async_client.models.las_wheretoobtainsubstance_icv import LASWheretoobtainsubstanceIcv
from typing import Optional, Set
from typing_extensions import Self

class Las2020List(BaseModel):
    """
    Fields in SharePoint list.
    """ # noqa: E501
    accommodation_comment: Optional[StrictStr] = Field(default=None, alias="AccommodationComment")
    acsf_time1: Optional[StrictStr] = Field(default=None, alias="ACSFTime1")
    acsf_time2: Optional[StrictStr] = Field(default=None, alias="ACSFTime2")
    acsf_time3: Optional[StrictStr] = Field(default=None, alias="ACSFTime3")
    acsf_time4: Optional[StrictStr] = Field(default=None, alias="ACSFTime4")
    acsf_time5: Optional[StrictStr] = Field(default=None, alias="ACSFTime5")
    acsfid1: Optional[StrictStr] = Field(default=None, alias="ACSFID1")
    acsfid2: Optional[StrictStr] = Field(default=None, alias="ACSFID2")
    acsfid3: Optional[StrictStr] = Field(default=None, alias="ACSFID3")
    acsfid4: Optional[StrictStr] = Field(default=None, alias="ACSFID4")
    acsfid5: Optional[StrictStr] = Field(default=None, alias="ACSFID5")
    afternoon_pf: Optional[StrictBool] = Field(default=None, alias="AfternoonPF")
    animals_availableon_protocol: Optional[StrictBool] = Field(default=None, alias="AnimalsAvailableonProtocol")
    app_author: Optional[StrictStr] = Field(default=None, alias="AppAuthor")
    app_editor: Optional[StrictStr] = Field(default=None, alias="AppEditor")
    attachments: Optional[StrictBool] = Field(default=None, alias="Attachments")
    author: Optional[StrictStr] = Field(default=None, alias="Author")
    bc_age: Optional[StrictStr] = Field(default=None, alias="BCAge")
    bc_genotypes: Optional[StrictStr] = Field(default=None, alias="BCGenotypes")
    bc_location: Optional[StrictStr] = Field(default=None, alias="BCLocation")
    bc_tube: Optional[StrictStr] = Field(default=None, alias="BCTube")
    bc_type: Optional[LASBctype] = Field(default=None, alias="BCType")
    bc_volume: Optional[StrictStr] = Field(default=None, alias="BCVolume")
    color_tag: Optional[StrictStr] = Field(default=None, alias="_ColorTag")
    compliance_asset_id: Optional[StrictStr] = Field(default=None, alias="ComplianceAssetId")
    compliance_flags: Optional[StrictStr] = Field(default=None, alias="_ComplianceFlags")
    compliance_tag: Optional[StrictStr] = Field(default=None, alias="_ComplianceTag")
    compliance_tag_user_id: Optional[StrictStr] = Field(default=None, alias="_ComplianceTagUserId")
    compliance_tag_written_time: Optional[StrictStr] = Field(default=None, alias="_ComplianceTagWrittenTime")
    content_type: Optional[StrictStr] = Field(default=None, alias="ContentType")
    created: Optional[datetime] = Field(default=None, alias="Created")
    custcontact: Optional[StrictStr] = None
    custom_com1: Optional[StrictStr] = Field(default=None, alias="CustomCom1")
    custom_com2: Optional[StrictStr] = Field(default=None, alias="CustomCom2")
    custpresent: Optional[StrictBool] = None
    delivery_location: Optional[LASDeliverylocation] = Field(default=None, alias="DeliveryLocation")
    doc_icon: Optional[StrictStr] = Field(default=None, alias="DocIcon")
    dose_route: Optional[LASDoseroute] = Field(default=None, alias="doseRoute")
    dose_sub: Optional[StrictStr] = Field(default=None, alias="doseSub")
    dose_where: Optional[StrictStr] = Field(default=None, alias="doseWhere")
    doseduration: Optional[StrictStr] = None
    dosevolume: Optional[StrictStr] = None
    doxycycline: Optional[StrictBool] = Field(default=None, alias="Doxycycline")
    edit: Optional[StrictStr] = Field(default=None, alias="Edit")
    editor: Optional[StrictStr] = Field(default=None, alias="Editor")
    folder_child_count: Optional[StrictStr] = Field(default=None, alias="FolderChildCount")
    icv_comment: Optional[StrictStr] = Field(default=None, alias="icvComment")
    icv_id1: Optional[StrictStr] = Field(default=None, alias="icvID1")
    icv_id2: Optional[StrictStr] = Field(default=None, alias="icvID2")
    icv_id3: Optional[StrictStr] = Field(default=None, alias="icvID3")
    icv_id4: Optional[StrictStr] = Field(default=None, alias="icvID4")
    icv_id5: Optional[StrictStr] = Field(default=None, alias="icvID5")
    icv_lims: Optional[LASIcvlims] = Field(default=None, alias="icvLIMS")
    icv_route1: Optional[LASIcvroute1] = Field(default=None, alias="icvRoute1")
    icv_route2: Optional[LASIcvroute2] = Field(default=None, alias="icvRoute2")
    icv_route3: Optional[LASIcvroute3] = Field(default=None, alias="icvRoute3")
    icv_route4: Optional[LASIcvroute4] = Field(default=None, alias="icvRoute4")
    icv_route5: Optional[LASIcvroute5] = Field(default=None, alias="icvRoute5")
    icv_sub1: Optional[StrictStr] = Field(default=None, alias="icvSub1")
    icv_sub2: Optional[StrictStr] = Field(default=None, alias="icvSub2")
    icv_sub3: Optional[StrictStr] = Field(default=None, alias="icvSub3")
    icv_sub4: Optional[StrictStr] = Field(default=None, alias="icvSub4")
    icv_sub5: Optional[StrictStr] = Field(default=None, alias="icvSub5")
    id: Optional[StrictInt] = Field(default=None, alias="ID")
    is_record: Optional[StrictStr] = Field(default=None, alias="_IsRecord")
    item_child_count: Optional[StrictStr] = Field(default=None, alias="ItemChildCount")
    lta_id1: Optional[StrictStr] = Field(default=None, alias="LTaID1")
    lta_id2: Optional[StrictStr] = Field(default=None, alias="LTaID2")
    lta_id3: Optional[StrictStr] = Field(default=None, alias="LTaID3")
    lta_id4: Optional[StrictStr] = Field(default=None, alias="LTaID4")
    lta_id5: Optional[StrictStr] = Field(default=None, alias="LTaID5")
    l_tdate1: Optional[datetime] = Field(default=None, alias="LTdate1")
    l_tdate2: Optional[datetime] = Field(default=None, alias="LTdate2")
    l_tdate3: Optional[datetime] = Field(default=None, alias="LTdate3")
    l_tdate4: Optional[datetime] = Field(default=None, alias="LTdate4")
    l_tdate5: Optional[datetime] = Field(default=None, alias="LTdate5")
    las_comments: Optional[StrictStr] = Field(default=None, alias="LASComments")
    lims_entry: Optional[StrictBool] = Field(default=None, alias="LIMSEntry")
    lims_project: Optional[LASLimsproject] = Field(default=None, alias="LIMSProject")
    lims_workflow: Optional[LASLimsworkflow] = Field(default=None, alias="LIMSWorkflow")
    lims_workflow_x0020_2: Optional[LASLimsworkflow2] = Field(default=None, alias="LIMSWorkflow_x0020_2")
    link_title: Optional[StrictStr] = Field(default=None, alias="LinkTitle")
    link_title_no_menu: Optional[StrictStr] = Field(default=None, alias="LinkTitleNoMenu")
    lt_task1: Optional[StrictStr] = Field(default=None, alias="LTTask1")
    lt_task2: Optional[StrictStr] = Field(default=None, alias="LTTask2")
    lt_task3: Optional[StrictStr] = Field(default=None, alias="LTTask3")
    lt_task4: Optional[StrictStr] = Field(default=None, alias="LTTask4")
    lt_task5: Optional[StrictStr] = Field(default=None, alias="LTTask5")
    modified: Optional[datetime] = Field(default=None, alias="Modified")
    n_end_x0020_date: Optional[datetime] = Field(default=None, alias="nEnd_x0020_Date")
    n_roid1: Optional[StrictStr] = Field(default=None, alias="nROID1")
    n_roid2: Optional[StrictStr] = Field(default=None, alias="nROID2")
    n_roid3: Optional[StrictStr] = Field(default=None, alias="nROID3")
    n_roid4: Optional[StrictStr] = Field(default=None, alias="nROID4")
    n_roid5: Optional[StrictStr] = Field(default=None, alias="nROID5")
    n_start_x0020_date: Optional[datetime] = Field(default=None, alias="nStart_x0020_Date")
    oct: Optional[StrictBool] = Field(default=None, alias="OCT")
    post_fix: Optional[LASPostfix] = Field(default=None, alias="PostFix")
    project_id: Optional[LASProjectid] = Field(default=None, alias="ProjectID")
    project_lead2: Optional[StrictStr] = Field(default=None, alias="ProjectLead2")
    protocol: Optional[LASProtocol] = Field(default=None, alias="Protocol")
    qc_door_sheet: Optional[StrictBool] = Field(default=None, alias="QCDoorSheet")
    req_age1: Optional[StrictStr] = Field(default=None, alias="ReqAge1")
    req_age2: Optional[StrictStr] = Field(default=None, alias="ReqAge2")
    req_age3: Optional[StrictStr] = Field(default=None, alias="ReqAge3")
    req_age4: Optional[StrictStr] = Field(default=None, alias="ReqAge4")
    req_pro1: Optional[LASReqpro1] = Field(default=None, alias="ReqPro1")
    req_pro2: Optional[LASReqpro2] = Field(default=None, alias="ReqPro2")
    req_pro3: Optional[LASReqpro3] = Field(default=None, alias="ReqPro3")
    req_pro4: Optional[LASReqpro4] = Field(default=None, alias="ReqPro4")
    reqdate1: Optional[datetime] = Field(default=None, alias="Reqdate1")
    reqdate2: Optional[datetime] = Field(default=None, alias="Reqdate2")
    reqdate3: Optional[datetime] = Field(default=None, alias="Reqdate3")
    reqdate4: Optional[datetime] = Field(default=None, alias="Reqdate4")
    request_status2: Optional[LASRequeststatus2] = Field(default=None, description="New, In Progress, Complete, Cancelled", alias="RequestStatus2")
    ro_box1: Optional[StrictStr] = Field(default=None, alias="roBox1")
    ro_box2: Optional[StrictStr] = Field(default=None, alias="roBox2")
    ro_box3: Optional[StrictStr] = Field(default=None, alias="roBox3")
    ro_box4: Optional[StrictStr] = Field(default=None, alias="roBox4")
    ro_box5: Optional[StrictStr] = Field(default=None, alias="roBox5")
    ro_comment: Optional[StrictStr] = Field(default=None, alias="roComment")
    ro_discard: Optional[StrictBool] = Field(default=None, alias="roDiscard")
    ro_eye1: Optional[LASRoeye1] = Field(default=None, alias="roEye1")
    ro_eye2: Optional[LASRoeye2] = Field(default=None, alias="roEye2")
    ro_eye3: Optional[LASRoeye3] = Field(default=None, alias="roEye3")
    ro_eye4: Optional[LASRoeye4] = Field(default=None, alias="roEye4")
    ro_eye5: Optional[LASRoeye5] = Field(default=None, alias="roEye5")
    ro_gc1: Optional[StrictStr] = Field(default=None, alias="roGC1")
    ro_gc1b: Optional[StrictStr] = Field(default=None, alias="roGC1b")
    ro_gc1c: Optional[StrictStr] = Field(default=None, alias="roGC1c")
    ro_gc1d: Optional[StrictStr] = Field(default=None, alias="roGC1d")
    ro_gc2: Optional[StrictStr] = Field(default=None, alias="roGC2")
    ro_gc2b: Optional[StrictStr] = Field(default=None, alias="roGC2b")
    ro_gc2c: Optional[StrictStr] = Field(default=None, alias="roGC2c")
    ro_gc2d: Optional[StrictStr] = Field(default=None, alias="roGC2d")
    ro_gc3: Optional[StrictStr] = Field(default=None, alias="roGC3")
    ro_gc3b: Optional[StrictStr] = Field(default=None, alias="roGC3b")
    ro_gc3c: Optional[StrictStr] = Field(default=None, alias="roGC3c")
    ro_gc3d: Optional[StrictStr] = Field(default=None, alias="roGC3d")
    ro_gc4: Optional[StrictStr] = Field(default=None, alias="roGC4")
    ro_gc4b: Optional[StrictStr] = Field(default=None, alias="roGC4b")
    ro_gc4c: Optional[StrictStr] = Field(default=None, alias="roGC4c")
    ro_gc4d: Optional[StrictStr] = Field(default=None, alias="roGC4d")
    ro_gc5: Optional[StrictStr] = Field(default=None, alias="roGC5")
    ro_gc5b: Optional[StrictStr] = Field(default=None, alias="roGC5b")
    ro_gc5c: Optional[StrictStr] = Field(default=None, alias="roGC5c")
    ro_gc5d: Optional[StrictStr] = Field(default=None, alias="roGC5d")
    ro_ice: Optional[StrictBool] = Field(default=None, alias="roIce")
    ro_lims: Optional[LASRolims] = Field(default=None, alias="roLIMS")
    ro_lot1: Optional[StrictStr] = Field(default=None, alias="roLot1")
    ro_lot1b: Optional[StrictStr] = Field(default=None, alias="roLot1b")
    ro_lot1c: Optional[StrictStr] = Field(default=None, alias="roLot1c")
    ro_lot1d: Optional[StrictStr] = Field(default=None, alias="roLot1d")
    ro_lot2: Optional[StrictStr] = Field(default=None, alias="roLot2")
    ro_lot2b: Optional[StrictStr] = Field(default=None, alias="roLot2b")
    ro_lot2c: Optional[StrictStr] = Field(default=None, alias="roLot2c")
    ro_lot2d: Optional[StrictStr] = Field(default=None, alias="roLot2d")
    ro_lot3: Optional[StrictStr] = Field(default=None, alias="roLot3")
    ro_lot3b: Optional[StrictStr] = Field(default=None, alias="roLot3b")
    ro_lot3c: Optional[StrictStr] = Field(default=None, alias="roLot3c")
    ro_lot3d: Optional[StrictStr] = Field(default=None, alias="roLot3d")
    ro_lot4: Optional[StrictStr] = Field(default=None, alias="roLot4")
    ro_lot4b: Optional[StrictStr] = Field(default=None, alias="roLot4b")
    ro_lot4c: Optional[StrictStr] = Field(default=None, alias="roLot4c")
    ro_lot4d: Optional[StrictStr] = Field(default=None, alias="roLot4d")
    ro_lot5: Optional[StrictStr] = Field(default=None, alias="roLot5")
    ro_lot5b: Optional[StrictStr] = Field(default=None, alias="roLot5b")
    ro_lot5c: Optional[StrictStr] = Field(default=None, alias="roLot5c")
    ro_lot5d: Optional[StrictStr] = Field(default=None, alias="roLot5d")
    ro_sop: Optional[LASRosop] = Field(default=None, alias="roSOP")
    ro_spin_down: Optional[StrictBool] = Field(default=None, alias="roSpinDown")
    ro_sub1: Optional[StrictStr] = Field(default=None, alias="roSub1")
    ro_sub1b: Optional[StrictStr] = Field(default=None, alias="roSub1b")
    ro_sub1c: Optional[StrictStr] = Field(default=None, alias="roSub1c")
    ro_sub1d: Optional[StrictStr] = Field(default=None, alias="roSub1d")
    ro_sub2: Optional[StrictStr] = Field(default=None, alias="roSub2")
    ro_sub2b: Optional[StrictStr] = Field(default=None, alias="roSub2b")
    ro_sub2c: Optional[StrictStr] = Field(default=None, alias="roSub2c")
    ro_sub2d: Optional[StrictStr] = Field(default=None, alias="roSub2d")
    ro_sub3: Optional[StrictStr] = Field(default=None, alias="roSub3")
    ro_sub3b: Optional[StrictStr] = Field(default=None, alias="roSub3b")
    ro_sub3c: Optional[StrictStr] = Field(default=None, alias="roSub3c")
    ro_sub3d: Optional[StrictStr] = Field(default=None, alias="roSub3d")
    ro_sub4: Optional[StrictStr] = Field(default=None, alias="roSub4")
    ro_sub4b: Optional[StrictStr] = Field(default=None, alias="roSub4b")
    ro_sub4c: Optional[StrictStr] = Field(default=None, alias="roSub4c")
    ro_sub4d: Optional[StrictStr] = Field(default=None, alias="roSub4d")
    ro_sub5: Optional[StrictStr] = Field(default=None, alias="roSub5")
    ro_sub5b: Optional[StrictStr] = Field(default=None, alias="roSub5b")
    ro_sub5c: Optional[StrictStr] = Field(default=None, alias="roSub5c")
    ro_sub5d: Optional[StrictStr] = Field(default=None, alias="roSub5d")
    ro_tite1: Optional[StrictStr] = Field(default=None, alias="roTite1")
    ro_tite1b: Optional[StrictStr] = Field(default=None, alias="roTite1b")
    ro_tite1c: Optional[StrictStr] = Field(default=None, alias="roTite1c")
    ro_tite1d: Optional[StrictStr] = Field(default=None, alias="roTite1d")
    ro_tite2: Optional[StrictStr] = Field(default=None, alias="roTite2")
    ro_tite2b: Optional[StrictStr] = Field(default=None, alias="roTite2b")
    ro_tite2c: Optional[StrictStr] = Field(default=None, alias="roTite2c")
    ro_tite2d: Optional[StrictStr] = Field(default=None, alias="roTite2d")
    ro_tite3: Optional[StrictStr] = Field(default=None, alias="roTite3")
    ro_tite3b: Optional[StrictStr] = Field(default=None, alias="roTite3b")
    ro_tite3c: Optional[StrictStr] = Field(default=None, alias="roTite3c")
    ro_tite3d: Optional[StrictStr] = Field(default=None, alias="roTite3d")
    ro_tite4: Optional[StrictStr] = Field(default=None, alias="roTite4")
    ro_tite4b: Optional[StrictStr] = Field(default=None, alias="roTite4b")
    ro_tite4c: Optional[StrictStr] = Field(default=None, alias="roTite4c")
    ro_tite4d: Optional[StrictStr] = Field(default=None, alias="roTite4d")
    ro_tite5: Optional[StrictStr] = Field(default=None, alias="roTite5")
    ro_tite5b: Optional[StrictStr] = Field(default=None, alias="roTite5b")
    ro_tite5c: Optional[StrictStr] = Field(default=None, alias="roTite5c")
    ro_tite5d: Optional[StrictStr] = Field(default=None, alias="roTite5d")
    ro_tube1: Optional[StrictStr] = Field(default=None, alias="roTube1")
    ro_tube2: Optional[StrictStr] = Field(default=None, alias="roTube2")
    ro_tube3: Optional[StrictStr] = Field(default=None, alias="roTube3")
    ro_tube4: Optional[StrictStr] = Field(default=None, alias="roTube4")
    ro_tube5: Optional[StrictStr] = Field(default=None, alias="roTube5")
    ro_vol1: Optional[StrictStr] = Field(default=None, alias="roVol1")
    ro_vol2: Optional[StrictStr] = Field(default=None, alias="roVol2")
    ro_vol3: Optional[StrictStr] = Field(default=None, alias="roVol3")
    ro_vol4: Optional[StrictStr] = Field(default=None, alias="roVol4")
    ro_vol5: Optional[StrictStr] = Field(default=None, alias="roVol5")
    ro_vol_v1: Optional[StrictStr] = Field(default=None, alias="roVolV1")
    ro_vol_v1b: Optional[StrictStr] = Field(default=None, alias="roVolV1b")
    ro_vol_v1c: Optional[StrictStr] = Field(default=None, alias="roVolV1c")
    ro_vol_v1d: Optional[StrictStr] = Field(default=None, alias="roVolV1d")
    ro_vol_v2: Optional[StrictStr] = Field(default=None, alias="roVolV2")
    ro_vol_v2b: Optional[StrictStr] = Field(default=None, alias="roVolV2b")
    ro_vol_v2c: Optional[StrictStr] = Field(default=None, alias="roVolV2c")
    ro_vol_v2d: Optional[StrictStr] = Field(default=None, alias="roVolV2d")
    ro_vol_v3: Optional[StrictStr] = Field(default=None, alias="roVolV3")
    ro_vol_v3b: Optional[StrictStr] = Field(default=None, alias="roVolV3b")
    ro_vol_v3c: Optional[StrictStr] = Field(default=None, alias="roVolV3c")
    ro_vol_v3d: Optional[StrictStr] = Field(default=None, alias="roVolV3d")
    ro_vol_v4: Optional[StrictStr] = Field(default=None, alias="roVolV4")
    ro_vol_v4b: Optional[StrictStr] = Field(default=None, alias="roVolV4b")
    ro_vol_v4c: Optional[StrictStr] = Field(default=None, alias="roVolV4c")
    ro_vol_v4d: Optional[StrictStr] = Field(default=None, alias="roVolV4d")
    ro_vol_v5: Optional[StrictStr] = Field(default=None, alias="roVolV5")
    ro_vol_v5b: Optional[StrictStr] = Field(default=None, alias="roVolV5b")
    ro_vol_v5c: Optional[StrictStr] = Field(default=None, alias="roVolV5c")
    ro_vol_v5d: Optional[StrictStr] = Field(default=None, alias="roVolV5d")
    ro_where: Optional[LASRowhere] = Field(default=None, alias="roWhere")
    sign_x002d_off_x0020_status: Optional[StrictStr] = Field(default=None, alias="Sign_x002d_off_x0020_status")
    spec_deli_loc: Optional[StrictStr] = Field(default=None, alias="SpecDeliLoc")
    species: Optional[LASSpecies] = Field(default=None, alias="Species")
    tam: Optional[StrictBool] = Field(default=None, alias="TAM")
    tam_age: Optional[StrictStr] = Field(default=None, alias="TAMAge")
    tam_freq: Optional[LASTamFrequency] = Field(default=None, alias="TAMFreq")
    tc_prep: Optional[List[LASTcprep]] = Field(default=None, alias="TCPrep")
    tc_tiss: Optional[List[LASTctiss]] = Field(default=None, alias="TCTiss")
    title: Optional[StrictStr] = Field(default=None, alias="Title")
    tmp: Optional[StrictBool] = Field(default=None, alias="TMP")
    tmp_age: Optional[StrictStr] = Field(default=None, alias="TMPAge")
    tmp_freq: Optional[LASTmpFrequency] = Field(default=None, alias="TMPFreq")
    ui_version_string: Optional[StrictStr] = Field(default=None, alias="_UIVersionString")
    wellness_report_x0028_no_x002_f_ye: Optional[StrictBool] = Field(default=None, alias="WellnessReport_x0028_No_x002F_Ye")
    whereto_obtainsubstance_x0028_icv: Optional[LASWheretoobtainsubstanceIcv] = Field(default=None, alias="WheretoObtainsubstance_x0028_ICV")
    author_id: Optional[StrictInt] = Field(default=None, alias="AuthorId")
    author_lookup_id: Optional[StrictInt] = Field(default=None, alias="AuthorLookupId")
    editor_id: Optional[StrictInt] = Field(default=None, alias="EditorId")
    additional_properties: Dict[str, Any] = {}
    __properties: ClassVar[List[str]] = ["AccommodationComment", "ACSFTime1", "ACSFTime2", "ACSFTime3", "ACSFTime4", "ACSFTime5", "ACSFID1", "ACSFID2", "ACSFID3", "ACSFID4", "ACSFID5", "AfternoonPF", "AnimalsAvailableonProtocol", "AppAuthor", "AppEditor", "Attachments", "Author", "BCAge", "BCGenotypes", "BCLocation", "BCTube", "BCType", "BCVolume", "_ColorTag", "ComplianceAssetId", "_ComplianceFlags", "_ComplianceTag", "_ComplianceTagUserId", "_ComplianceTagWrittenTime", "ContentType", "Created", "custcontact", "CustomCom1", "CustomCom2", "custpresent", "DeliveryLocation", "DocIcon", "doseRoute", "doseSub", "doseWhere", "doseduration", "dosevolume", "Doxycycline", "Edit", "Editor", "FolderChildCount", "icvComment", "icvID1", "icvID2", "icvID3", "icvID4", "icvID5", "icvLIMS", "icvRoute1", "icvRoute2", "icvRoute3", "icvRoute4", "icvRoute5", "icvSub1", "icvSub2", "icvSub3", "icvSub4", "icvSub5", "ID", "_IsRecord", "ItemChildCount", "LTaID1", "LTaID2", "LTaID3", "LTaID4", "LTaID5", "LTdate1", "LTdate2", "LTdate3", "LTdate4", "LTdate5", "LASComments", "LIMSEntry", "LIMSProject", "LIMSWorkflow", "LIMSWorkflow_x0020_2", "LinkTitle", "LinkTitleNoMenu", "LTTask1", "LTTask2", "LTTask3", "LTTask4", "LTTask5", "Modified", "nEnd_x0020_Date", "nROID1", "nROID2", "nROID3", "nROID4", "nROID5", "nStart_x0020_Date", "OCT", "PostFix", "ProjectID", "ProjectLead2", "Protocol", "QCDoorSheet", "ReqAge1", "ReqAge2", "ReqAge3", "ReqAge4", "ReqPro1", "ReqPro2", "ReqPro3", "ReqPro4", "Reqdate1", "Reqdate2", "Reqdate3", "Reqdate4", "RequestStatus2", "roBox1", "roBox2", "roBox3", "roBox4", "roBox5", "roComment", "roDiscard", "roEye1", "roEye2", "roEye3", "roEye4", "roEye5", "roGC1", "roGC1b", "roGC1c", "roGC1d", "roGC2", "roGC2b", "roGC2c", "roGC2d", "roGC3", "roGC3b", "roGC3c", "roGC3d", "roGC4", "roGC4b", "roGC4c", "roGC4d", "roGC5", "roGC5b", "roGC5c", "roGC5d", "roIce", "roLIMS", "roLot1", "roLot1b", "roLot1c", "roLot1d", "roLot2", "roLot2b", "roLot2c", "roLot2d", "roLot3", "roLot3b", "roLot3c", "roLot3d", "roLot4", "roLot4b", "roLot4c", "roLot4d", "roLot5", "roLot5b", "roLot5c", "roLot5d", "roSOP", "roSpinDown", "roSub1", "roSub1b", "roSub1c", "roSub1d", "roSub2", "roSub2b", "roSub2c", "roSub2d", "roSub3", "roSub3b", "roSub3c", "roSub3d", "roSub4", "roSub4b", "roSub4c", "roSub4d", "roSub5", "roSub5b", "roSub5c", "roSub5d", "roTite1", "roTite1b", "roTite1c", "roTite1d", "roTite2", "roTite2b", "roTite2c", "roTite2d", "roTite3", "roTite3b", "roTite3c", "roTite3d", "roTite4", "roTite4b", "roTite4c", "roTite4d", "roTite5", "roTite5b", "roTite5c", "roTite5d", "roTube1", "roTube2", "roTube3", "roTube4", "roTube5", "roVol1", "roVol2", "roVol3", "roVol4", "roVol5", "roVolV1", "roVolV1b", "roVolV1c", "roVolV1d", "roVolV2", "roVolV2b", "roVolV2c", "roVolV2d", "roVolV3", "roVolV3b", "roVolV3c", "roVolV3d", "roVolV4", "roVolV4b", "roVolV4c", "roVolV4d", "roVolV5", "roVolV5b", "roVolV5c", "roVolV5d", "roWhere", "Sign_x002d_off_x0020_status", "SpecDeliLoc", "Species", "TAM", "TAMAge", "TAMFreq", "TCPrep", "TCTiss", "Title", "TMP", "TMPAge", "TMPFreq", "_UIVersionString", "WellnessReport_x0028_No_x002F_Ye", "WheretoObtainsubstance_x0028_ICV", "AuthorId", "AuthorLookupId", "EditorId"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Las2020List from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * Fields in `self.additional_properties` are added to the output dict.
        """
        excluded_fields: Set[str] = set([
            "additional_properties",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        # set to None if accommodation_comment (nullable) is None
        # and model_fields_set contains the field
        if self.accommodation_comment is None and "accommodation_comment" in self.model_fields_set:
            _dict['AccommodationComment'] = None

        # set to None if acsf_time1 (nullable) is None
        # and model_fields_set contains the field
        if self.acsf_time1 is None and "acsf_time1" in self.model_fields_set:
            _dict['ACSFTime1'] = None

        # set to None if acsf_time2 (nullable) is None
        # and model_fields_set contains the field
        if self.acsf_time2 is None and "acsf_time2" in self.model_fields_set:
            _dict['ACSFTime2'] = None

        # set to None if acsf_time3 (nullable) is None
        # and model_fields_set contains the field
        if self.acsf_time3 is None and "acsf_time3" in self.model_fields_set:
            _dict['ACSFTime3'] = None

        # set to None if acsf_time4 (nullable) is None
        # and model_fields_set contains the field
        if self.acsf_time4 is None and "acsf_time4" in self.model_fields_set:
            _dict['ACSFTime4'] = None

        # set to None if acsf_time5 (nullable) is None
        # and model_fields_set contains the field
        if self.acsf_time5 is None and "acsf_time5" in self.model_fields_set:
            _dict['ACSFTime5'] = None

        # set to None if acsfid1 (nullable) is None
        # and model_fields_set contains the field
        if self.acsfid1 is None and "acsfid1" in self.model_fields_set:
            _dict['ACSFID1'] = None

        # set to None if acsfid2 (nullable) is None
        # and model_fields_set contains the field
        if self.acsfid2 is None and "acsfid2" in self.model_fields_set:
            _dict['ACSFID2'] = None

        # set to None if acsfid3 (nullable) is None
        # and model_fields_set contains the field
        if self.acsfid3 is None and "acsfid3" in self.model_fields_set:
            _dict['ACSFID3'] = None

        # set to None if acsfid4 (nullable) is None
        # and model_fields_set contains the field
        if self.acsfid4 is None and "acsfid4" in self.model_fields_set:
            _dict['ACSFID4'] = None

        # set to None if acsfid5 (nullable) is None
        # and model_fields_set contains the field
        if self.acsfid5 is None and "acsfid5" in self.model_fields_set:
            _dict['ACSFID5'] = None

        # set to None if afternoon_pf (nullable) is None
        # and model_fields_set contains the field
        if self.afternoon_pf is None and "afternoon_pf" in self.model_fields_set:
            _dict['AfternoonPF'] = None

        # set to None if animals_availableon_protocol (nullable) is None
        # and model_fields_set contains the field
        if self.animals_availableon_protocol is None and "animals_availableon_protocol" in self.model_fields_set:
            _dict['AnimalsAvailableonProtocol'] = None

        # set to None if app_author (nullable) is None
        # and model_fields_set contains the field
        if self.app_author is None and "app_author" in self.model_fields_set:
            _dict['AppAuthor'] = None

        # set to None if app_editor (nullable) is None
        # and model_fields_set contains the field
        if self.app_editor is None and "app_editor" in self.model_fields_set:
            _dict['AppEditor'] = None

        # set to None if attachments (nullable) is None
        # and model_fields_set contains the field
        if self.attachments is None and "attachments" in self.model_fields_set:
            _dict['Attachments'] = None

        # set to None if author (nullable) is None
        # and model_fields_set contains the field
        if self.author is None and "author" in self.model_fields_set:
            _dict['Author'] = None

        # set to None if bc_age (nullable) is None
        # and model_fields_set contains the field
        if self.bc_age is None and "bc_age" in self.model_fields_set:
            _dict['BCAge'] = None

        # set to None if bc_genotypes (nullable) is None
        # and model_fields_set contains the field
        if self.bc_genotypes is None and "bc_genotypes" in self.model_fields_set:
            _dict['BCGenotypes'] = None

        # set to None if bc_location (nullable) is None
        # and model_fields_set contains the field
        if self.bc_location is None and "bc_location" in self.model_fields_set:
            _dict['BCLocation'] = None

        # set to None if bc_tube (nullable) is None
        # and model_fields_set contains the field
        if self.bc_tube is None and "bc_tube" in self.model_fields_set:
            _dict['BCTube'] = None

        # set to None if bc_volume (nullable) is None
        # and model_fields_set contains the field
        if self.bc_volume is None and "bc_volume" in self.model_fields_set:
            _dict['BCVolume'] = None

        # set to None if color_tag (nullable) is None
        # and model_fields_set contains the field
        if self.color_tag is None and "color_tag" in self.model_fields_set:
            _dict['_ColorTag'] = None

        # set to None if compliance_asset_id (nullable) is None
        # and model_fields_set contains the field
        if self.compliance_asset_id is None and "compliance_asset_id" in self.model_fields_set:
            _dict['ComplianceAssetId'] = None

        # set to None if compliance_flags (nullable) is None
        # and model_fields_set contains the field
        if self.compliance_flags is None and "compliance_flags" in self.model_fields_set:
            _dict['_ComplianceFlags'] = None

        # set to None if compliance_tag (nullable) is None
        # and model_fields_set contains the field
        if self.compliance_tag is None and "compliance_tag" in self.model_fields_set:
            _dict['_ComplianceTag'] = None

        # set to None if compliance_tag_user_id (nullable) is None
        # and model_fields_set contains the field
        if self.compliance_tag_user_id is None and "compliance_tag_user_id" in self.model_fields_set:
            _dict['_ComplianceTagUserId'] = None

        # set to None if compliance_tag_written_time (nullable) is None
        # and model_fields_set contains the field
        if self.compliance_tag_written_time is None and "compliance_tag_written_time" in self.model_fields_set:
            _dict['_ComplianceTagWrittenTime'] = None

        # set to None if content_type (nullable) is None
        # and model_fields_set contains the field
        if self.content_type is None and "content_type" in self.model_fields_set:
            _dict['ContentType'] = None

        # set to None if created (nullable) is None
        # and model_fields_set contains the field
        if self.created is None and "created" in self.model_fields_set:
            _dict['Created'] = None

        # set to None if custcontact (nullable) is None
        # and model_fields_set contains the field
        if self.custcontact is None and "custcontact" in self.model_fields_set:
            _dict['custcontact'] = None

        # set to None if custom_com1 (nullable) is None
        # and model_fields_set contains the field
        if self.custom_com1 is None and "custom_com1" in self.model_fields_set:
            _dict['CustomCom1'] = None

        # set to None if custom_com2 (nullable) is None
        # and model_fields_set contains the field
        if self.custom_com2 is None and "custom_com2" in self.model_fields_set:
            _dict['CustomCom2'] = None

        # set to None if custpresent (nullable) is None
        # and model_fields_set contains the field
        if self.custpresent is None and "custpresent" in self.model_fields_set:
            _dict['custpresent'] = None

        # set to None if doc_icon (nullable) is None
        # and model_fields_set contains the field
        if self.doc_icon is None and "doc_icon" in self.model_fields_set:
            _dict['DocIcon'] = None

        # set to None if dose_sub (nullable) is None
        # and model_fields_set contains the field
        if self.dose_sub is None and "dose_sub" in self.model_fields_set:
            _dict['doseSub'] = None

        # set to None if dose_where (nullable) is None
        # and model_fields_set contains the field
        if self.dose_where is None and "dose_where" in self.model_fields_set:
            _dict['doseWhere'] = None

        # set to None if doseduration (nullable) is None
        # and model_fields_set contains the field
        if self.doseduration is None and "doseduration" in self.model_fields_set:
            _dict['doseduration'] = None

        # set to None if dosevolume (nullable) is None
        # and model_fields_set contains the field
        if self.dosevolume is None and "dosevolume" in self.model_fields_set:
            _dict['dosevolume'] = None

        # set to None if doxycycline (nullable) is None
        # and model_fields_set contains the field
        if self.doxycycline is None and "doxycycline" in self.model_fields_set:
            _dict['Doxycycline'] = None

        # set to None if edit (nullable) is None
        # and model_fields_set contains the field
        if self.edit is None and "edit" in self.model_fields_set:
            _dict['Edit'] = None

        # set to None if editor (nullable) is None
        # and model_fields_set contains the field
        if self.editor is None and "editor" in self.model_fields_set:
            _dict['Editor'] = None

        # set to None if folder_child_count (nullable) is None
        # and model_fields_set contains the field
        if self.folder_child_count is None and "folder_child_count" in self.model_fields_set:
            _dict['FolderChildCount'] = None

        # set to None if icv_comment (nullable) is None
        # and model_fields_set contains the field
        if self.icv_comment is None and "icv_comment" in self.model_fields_set:
            _dict['icvComment'] = None

        # set to None if icv_id1 (nullable) is None
        # and model_fields_set contains the field
        if self.icv_id1 is None and "icv_id1" in self.model_fields_set:
            _dict['icvID1'] = None

        # set to None if icv_id2 (nullable) is None
        # and model_fields_set contains the field
        if self.icv_id2 is None and "icv_id2" in self.model_fields_set:
            _dict['icvID2'] = None

        # set to None if icv_id3 (nullable) is None
        # and model_fields_set contains the field
        if self.icv_id3 is None and "icv_id3" in self.model_fields_set:
            _dict['icvID3'] = None

        # set to None if icv_id4 (nullable) is None
        # and model_fields_set contains the field
        if self.icv_id4 is None and "icv_id4" in self.model_fields_set:
            _dict['icvID4'] = None

        # set to None if icv_id5 (nullable) is None
        # and model_fields_set contains the field
        if self.icv_id5 is None and "icv_id5" in self.model_fields_set:
            _dict['icvID5'] = None

        # set to None if icv_sub1 (nullable) is None
        # and model_fields_set contains the field
        if self.icv_sub1 is None and "icv_sub1" in self.model_fields_set:
            _dict['icvSub1'] = None

        # set to None if icv_sub2 (nullable) is None
        # and model_fields_set contains the field
        if self.icv_sub2 is None and "icv_sub2" in self.model_fields_set:
            _dict['icvSub2'] = None

        # set to None if icv_sub3 (nullable) is None
        # and model_fields_set contains the field
        if self.icv_sub3 is None and "icv_sub3" in self.model_fields_set:
            _dict['icvSub3'] = None

        # set to None if icv_sub4 (nullable) is None
        # and model_fields_set contains the field
        if self.icv_sub4 is None and "icv_sub4" in self.model_fields_set:
            _dict['icvSub4'] = None

        # set to None if icv_sub5 (nullable) is None
        # and model_fields_set contains the field
        if self.icv_sub5 is None and "icv_sub5" in self.model_fields_set:
            _dict['icvSub5'] = None

        # set to None if id (nullable) is None
        # and model_fields_set contains the field
        if self.id is None and "id" in self.model_fields_set:
            _dict['ID'] = None

        # set to None if is_record (nullable) is None
        # and model_fields_set contains the field
        if self.is_record is None and "is_record" in self.model_fields_set:
            _dict['_IsRecord'] = None

        # set to None if item_child_count (nullable) is None
        # and model_fields_set contains the field
        if self.item_child_count is None and "item_child_count" in self.model_fields_set:
            _dict['ItemChildCount'] = None

        # set to None if lta_id1 (nullable) is None
        # and model_fields_set contains the field
        if self.lta_id1 is None and "lta_id1" in self.model_fields_set:
            _dict['LTaID1'] = None

        # set to None if lta_id2 (nullable) is None
        # and model_fields_set contains the field
        if self.lta_id2 is None and "lta_id2" in self.model_fields_set:
            _dict['LTaID2'] = None

        # set to None if lta_id3 (nullable) is None
        # and model_fields_set contains the field
        if self.lta_id3 is None and "lta_id3" in self.model_fields_set:
            _dict['LTaID3'] = None

        # set to None if lta_id4 (nullable) is None
        # and model_fields_set contains the field
        if self.lta_id4 is None and "lta_id4" in self.model_fields_set:
            _dict['LTaID4'] = None

        # set to None if lta_id5 (nullable) is None
        # and model_fields_set contains the field
        if self.lta_id5 is None and "lta_id5" in self.model_fields_set:
            _dict['LTaID5'] = None

        # set to None if l_tdate1 (nullable) is None
        # and model_fields_set contains the field
        if self.l_tdate1 is None and "l_tdate1" in self.model_fields_set:
            _dict['LTdate1'] = None

        # set to None if l_tdate2 (nullable) is None
        # and model_fields_set contains the field
        if self.l_tdate2 is None and "l_tdate2" in self.model_fields_set:
            _dict['LTdate2'] = None

        # set to None if l_tdate3 (nullable) is None
        # and model_fields_set contains the field
        if self.l_tdate3 is None and "l_tdate3" in self.model_fields_set:
            _dict['LTdate3'] = None

        # set to None if l_tdate4 (nullable) is None
        # and model_fields_set contains the field
        if self.l_tdate4 is None and "l_tdate4" in self.model_fields_set:
            _dict['LTdate4'] = None

        # set to None if l_tdate5 (nullable) is None
        # and model_fields_set contains the field
        if self.l_tdate5 is None and "l_tdate5" in self.model_fields_set:
            _dict['LTdate5'] = None

        # set to None if las_comments (nullable) is None
        # and model_fields_set contains the field
        if self.las_comments is None and "las_comments" in self.model_fields_set:
            _dict['LASComments'] = None

        # set to None if lims_entry (nullable) is None
        # and model_fields_set contains the field
        if self.lims_entry is None and "lims_entry" in self.model_fields_set:
            _dict['LIMSEntry'] = None

        # set to None if link_title (nullable) is None
        # and model_fields_set contains the field
        if self.link_title is None and "link_title" in self.model_fields_set:
            _dict['LinkTitle'] = None

        # set to None if link_title_no_menu (nullable) is None
        # and model_fields_set contains the field
        if self.link_title_no_menu is None and "link_title_no_menu" in self.model_fields_set:
            _dict['LinkTitleNoMenu'] = None

        # set to None if lt_task1 (nullable) is None
        # and model_fields_set contains the field
        if self.lt_task1 is None and "lt_task1" in self.model_fields_set:
            _dict['LTTask1'] = None

        # set to None if lt_task2 (nullable) is None
        # and model_fields_set contains the field
        if self.lt_task2 is None and "lt_task2" in self.model_fields_set:
            _dict['LTTask2'] = None

        # set to None if lt_task3 (nullable) is None
        # and model_fields_set contains the field
        if self.lt_task3 is None and "lt_task3" in self.model_fields_set:
            _dict['LTTask3'] = None

        # set to None if lt_task4 (nullable) is None
        # and model_fields_set contains the field
        if self.lt_task4 is None and "lt_task4" in self.model_fields_set:
            _dict['LTTask4'] = None

        # set to None if lt_task5 (nullable) is None
        # and model_fields_set contains the field
        if self.lt_task5 is None and "lt_task5" in self.model_fields_set:
            _dict['LTTask5'] = None

        # set to None if modified (nullable) is None
        # and model_fields_set contains the field
        if self.modified is None and "modified" in self.model_fields_set:
            _dict['Modified'] = None

        # set to None if n_end_x0020_date (nullable) is None
        # and model_fields_set contains the field
        if self.n_end_x0020_date is None and "n_end_x0020_date" in self.model_fields_set:
            _dict['nEnd_x0020_Date'] = None

        # set to None if n_roid1 (nullable) is None
        # and model_fields_set contains the field
        if self.n_roid1 is None and "n_roid1" in self.model_fields_set:
            _dict['nROID1'] = None

        # set to None if n_roid2 (nullable) is None
        # and model_fields_set contains the field
        if self.n_roid2 is None and "n_roid2" in self.model_fields_set:
            _dict['nROID2'] = None

        # set to None if n_roid3 (nullable) is None
        # and model_fields_set contains the field
        if self.n_roid3 is None and "n_roid3" in self.model_fields_set:
            _dict['nROID3'] = None

        # set to None if n_roid4 (nullable) is None
        # and model_fields_set contains the field
        if self.n_roid4 is None and "n_roid4" in self.model_fields_set:
            _dict['nROID4'] = None

        # set to None if n_roid5 (nullable) is None
        # and model_fields_set contains the field
        if self.n_roid5 is None and "n_roid5" in self.model_fields_set:
            _dict['nROID5'] = None

        # set to None if n_start_x0020_date (nullable) is None
        # and model_fields_set contains the field
        if self.n_start_x0020_date is None and "n_start_x0020_date" in self.model_fields_set:
            _dict['nStart_x0020_Date'] = None

        # set to None if oct (nullable) is None
        # and model_fields_set contains the field
        if self.oct is None and "oct" in self.model_fields_set:
            _dict['OCT'] = None

        # set to None if project_lead2 (nullable) is None
        # and model_fields_set contains the field
        if self.project_lead2 is None and "project_lead2" in self.model_fields_set:
            _dict['ProjectLead2'] = None

        # set to None if qc_door_sheet (nullable) is None
        # and model_fields_set contains the field
        if self.qc_door_sheet is None and "qc_door_sheet" in self.model_fields_set:
            _dict['QCDoorSheet'] = None

        # set to None if req_age1 (nullable) is None
        # and model_fields_set contains the field
        if self.req_age1 is None and "req_age1" in self.model_fields_set:
            _dict['ReqAge1'] = None

        # set to None if req_age2 (nullable) is None
        # and model_fields_set contains the field
        if self.req_age2 is None and "req_age2" in self.model_fields_set:
            _dict['ReqAge2'] = None

        # set to None if req_age3 (nullable) is None
        # and model_fields_set contains the field
        if self.req_age3 is None and "req_age3" in self.model_fields_set:
            _dict['ReqAge3'] = None

        # set to None if req_age4 (nullable) is None
        # and model_fields_set contains the field
        if self.req_age4 is None and "req_age4" in self.model_fields_set:
            _dict['ReqAge4'] = None

        # set to None if reqdate1 (nullable) is None
        # and model_fields_set contains the field
        if self.reqdate1 is None and "reqdate1" in self.model_fields_set:
            _dict['Reqdate1'] = None

        # set to None if reqdate2 (nullable) is None
        # and model_fields_set contains the field
        if self.reqdate2 is None and "reqdate2" in self.model_fields_set:
            _dict['Reqdate2'] = None

        # set to None if reqdate3 (nullable) is None
        # and model_fields_set contains the field
        if self.reqdate3 is None and "reqdate3" in self.model_fields_set:
            _dict['Reqdate3'] = None

        # set to None if reqdate4 (nullable) is None
        # and model_fields_set contains the field
        if self.reqdate4 is None and "reqdate4" in self.model_fields_set:
            _dict['Reqdate4'] = None

        # set to None if ro_box1 (nullable) is None
        # and model_fields_set contains the field
        if self.ro_box1 is None and "ro_box1" in self.model_fields_set:
            _dict['roBox1'] = None

        # set to None if ro_box2 (nullable) is None
        # and model_fields_set contains the field
        if self.ro_box2 is None and "ro_box2" in self.model_fields_set:
            _dict['roBox2'] = None

        # set to None if ro_box3 (nullable) is None
        # and model_fields_set contains the field
        if self.ro_box3 is None and "ro_box3" in self.model_fields_set:
            _dict['roBox3'] = None

        # set to None if ro_box4 (nullable) is None
        # and model_fields_set contains the field
        if self.ro_box4 is None and "ro_box4" in self.model_fields_set:
            _dict['roBox4'] = None

        # set to None if ro_box5 (nullable) is None
        # and model_fields_set contains the field
        if self.ro_box5 is None and "ro_box5" in self.model_fields_set:
            _dict['roBox5'] = None

        # set to None if ro_comment (nullable) is None
        # and model_fields_set contains the field
        if self.ro_comment is None and "ro_comment" in self.model_fields_set:
            _dict['roComment'] = None

        # set to None if ro_discard (nullable) is None
        # and model_fields_set contains the field
        if self.ro_discard is None and "ro_discard" in self.model_fields_set:
            _dict['roDiscard'] = None

        # set to None if ro_gc1 (nullable) is None
        # and model_fields_set contains the field
        if self.ro_gc1 is None and "ro_gc1" in self.model_fields_set:
            _dict['roGC1'] = None

        # set to None if ro_gc1b (nullable) is None
        # and model_fields_set contains the field
        if self.ro_gc1b is None and "ro_gc1b" in self.model_fields_set:
            _dict['roGC1b'] = None

        # set to None if ro_gc1c (nullable) is None
        # and model_fields_set contains the field
        if self.ro_gc1c is None and "ro_gc1c" in self.model_fields_set:
            _dict['roGC1c'] = None

        # set to None if ro_gc1d (nullable) is None
        # and model_fields_set contains the field
        if self.ro_gc1d is None and "ro_gc1d" in self.model_fields_set:
            _dict['roGC1d'] = None

        # set to None if ro_gc2 (nullable) is None
        # and model_fields_set contains the field
        if self.ro_gc2 is None and "ro_gc2" in self.model_fields_set:
            _dict['roGC2'] = None

        # set to None if ro_gc2b (nullable) is None
        # and model_fields_set contains the field
        if self.ro_gc2b is None and "ro_gc2b" in self.model_fields_set:
            _dict['roGC2b'] = None

        # set to None if ro_gc2c (nullable) is None
        # and model_fields_set contains the field
        if self.ro_gc2c is None and "ro_gc2c" in self.model_fields_set:
            _dict['roGC2c'] = None

        # set to None if ro_gc2d (nullable) is None
        # and model_fields_set contains the field
        if self.ro_gc2d is None and "ro_gc2d" in self.model_fields_set:
            _dict['roGC2d'] = None

        # set to None if ro_gc3 (nullable) is None
        # and model_fields_set contains the field
        if self.ro_gc3 is None and "ro_gc3" in self.model_fields_set:
            _dict['roGC3'] = None

        # set to None if ro_gc3b (nullable) is None
        # and model_fields_set contains the field
        if self.ro_gc3b is None and "ro_gc3b" in self.model_fields_set:
            _dict['roGC3b'] = None

        # set to None if ro_gc3c (nullable) is None
        # and model_fields_set contains the field
        if self.ro_gc3c is None and "ro_gc3c" in self.model_fields_set:
            _dict['roGC3c'] = None

        # set to None if ro_gc3d (nullable) is None
        # and model_fields_set contains the field
        if self.ro_gc3d is None and "ro_gc3d" in self.model_fields_set:
            _dict['roGC3d'] = None

        # set to None if ro_gc4 (nullable) is None
        # and model_fields_set contains the field
        if self.ro_gc4 is None and "ro_gc4" in self.model_fields_set:
            _dict['roGC4'] = None

        # set to None if ro_gc4b (nullable) is None
        # and model_fields_set contains the field
        if self.ro_gc4b is None and "ro_gc4b" in self.model_fields_set:
            _dict['roGC4b'] = None

        # set to None if ro_gc4c (nullable) is None
        # and model_fields_set contains the field
        if self.ro_gc4c is None and "ro_gc4c" in self.model_fields_set:
            _dict['roGC4c'] = None

        # set to None if ro_gc4d (nullable) is None
        # and model_fields_set contains the field
        if self.ro_gc4d is None and "ro_gc4d" in self.model_fields_set:
            _dict['roGC4d'] = None

        # set to None if ro_gc5 (nullable) is None
        # and model_fields_set contains the field
        if self.ro_gc5 is None and "ro_gc5" in self.model_fields_set:
            _dict['roGC5'] = None

        # set to None if ro_gc5b (nullable) is None
        # and model_fields_set contains the field
        if self.ro_gc5b is None and "ro_gc5b" in self.model_fields_set:
            _dict['roGC5b'] = None

        # set to None if ro_gc5c (nullable) is None
        # and model_fields_set contains the field
        if self.ro_gc5c is None and "ro_gc5c" in self.model_fields_set:
            _dict['roGC5c'] = None

        # set to None if ro_gc5d (nullable) is None
        # and model_fields_set contains the field
        if self.ro_gc5d is None and "ro_gc5d" in self.model_fields_set:
            _dict['roGC5d'] = None

        # set to None if ro_ice (nullable) is None
        # and model_fields_set contains the field
        if self.ro_ice is None and "ro_ice" in self.model_fields_set:
            _dict['roIce'] = None

        # set to None if ro_lot1 (nullable) is None
        # and model_fields_set contains the field
        if self.ro_lot1 is None and "ro_lot1" in self.model_fields_set:
            _dict['roLot1'] = None

        # set to None if ro_lot1b (nullable) is None
        # and model_fields_set contains the field
        if self.ro_lot1b is None and "ro_lot1b" in self.model_fields_set:
            _dict['roLot1b'] = None

        # set to None if ro_lot1c (nullable) is None
        # and model_fields_set contains the field
        if self.ro_lot1c is None and "ro_lot1c" in self.model_fields_set:
            _dict['roLot1c'] = None

        # set to None if ro_lot1d (nullable) is None
        # and model_fields_set contains the field
        if self.ro_lot1d is None and "ro_lot1d" in self.model_fields_set:
            _dict['roLot1d'] = None

        # set to None if ro_lot2 (nullable) is None
        # and model_fields_set contains the field
        if self.ro_lot2 is None and "ro_lot2" in self.model_fields_set:
            _dict['roLot2'] = None

        # set to None if ro_lot2b (nullable) is None
        # and model_fields_set contains the field
        if self.ro_lot2b is None and "ro_lot2b" in self.model_fields_set:
            _dict['roLot2b'] = None

        # set to None if ro_lot2c (nullable) is None
        # and model_fields_set contains the field
        if self.ro_lot2c is None and "ro_lot2c" in self.model_fields_set:
            _dict['roLot2c'] = None

        # set to None if ro_lot2d (nullable) is None
        # and model_fields_set contains the field
        if self.ro_lot2d is None and "ro_lot2d" in self.model_fields_set:
            _dict['roLot2d'] = None

        # set to None if ro_lot3 (nullable) is None
        # and model_fields_set contains the field
        if self.ro_lot3 is None and "ro_lot3" in self.model_fields_set:
            _dict['roLot3'] = None

        # set to None if ro_lot3b (nullable) is None
        # and model_fields_set contains the field
        if self.ro_lot3b is None and "ro_lot3b" in self.model_fields_set:
            _dict['roLot3b'] = None

        # set to None if ro_lot3c (nullable) is None
        # and model_fields_set contains the field
        if self.ro_lot3c is None and "ro_lot3c" in self.model_fields_set:
            _dict['roLot3c'] = None

        # set to None if ro_lot3d (nullable) is None
        # and model_fields_set contains the field
        if self.ro_lot3d is None and "ro_lot3d" in self.model_fields_set:
            _dict['roLot3d'] = None

        # set to None if ro_lot4 (nullable) is None
        # and model_fields_set contains the field
        if self.ro_lot4 is None and "ro_lot4" in self.model_fields_set:
            _dict['roLot4'] = None

        # set to None if ro_lot4b (nullable) is None
        # and model_fields_set contains the field
        if self.ro_lot4b is None and "ro_lot4b" in self.model_fields_set:
            _dict['roLot4b'] = None

        # set to None if ro_lot4c (nullable) is None
        # and model_fields_set contains the field
        if self.ro_lot4c is None and "ro_lot4c" in self.model_fields_set:
            _dict['roLot4c'] = None

        # set to None if ro_lot4d (nullable) is None
        # and model_fields_set contains the field
        if self.ro_lot4d is None and "ro_lot4d" in self.model_fields_set:
            _dict['roLot4d'] = None

        # set to None if ro_lot5 (nullable) is None
        # and model_fields_set contains the field
        if self.ro_lot5 is None and "ro_lot5" in self.model_fields_set:
            _dict['roLot5'] = None

        # set to None if ro_lot5b (nullable) is None
        # and model_fields_set contains the field
        if self.ro_lot5b is None and "ro_lot5b" in self.model_fields_set:
            _dict['roLot5b'] = None

        # set to None if ro_lot5c (nullable) is None
        # and model_fields_set contains the field
        if self.ro_lot5c is None and "ro_lot5c" in self.model_fields_set:
            _dict['roLot5c'] = None

        # set to None if ro_lot5d (nullable) is None
        # and model_fields_set contains the field
        if self.ro_lot5d is None and "ro_lot5d" in self.model_fields_set:
            _dict['roLot5d'] = None

        # set to None if ro_spin_down (nullable) is None
        # and model_fields_set contains the field
        if self.ro_spin_down is None and "ro_spin_down" in self.model_fields_set:
            _dict['roSpinDown'] = None

        # set to None if ro_sub1 (nullable) is None
        # and model_fields_set contains the field
        if self.ro_sub1 is None and "ro_sub1" in self.model_fields_set:
            _dict['roSub1'] = None

        # set to None if ro_sub1b (nullable) is None
        # and model_fields_set contains the field
        if self.ro_sub1b is None and "ro_sub1b" in self.model_fields_set:
            _dict['roSub1b'] = None

        # set to None if ro_sub1c (nullable) is None
        # and model_fields_set contains the field
        if self.ro_sub1c is None and "ro_sub1c" in self.model_fields_set:
            _dict['roSub1c'] = None

        # set to None if ro_sub1d (nullable) is None
        # and model_fields_set contains the field
        if self.ro_sub1d is None and "ro_sub1d" in self.model_fields_set:
            _dict['roSub1d'] = None

        # set to None if ro_sub2 (nullable) is None
        # and model_fields_set contains the field
        if self.ro_sub2 is None and "ro_sub2" in self.model_fields_set:
            _dict['roSub2'] = None

        # set to None if ro_sub2b (nullable) is None
        # and model_fields_set contains the field
        if self.ro_sub2b is None and "ro_sub2b" in self.model_fields_set:
            _dict['roSub2b'] = None

        # set to None if ro_sub2c (nullable) is None
        # and model_fields_set contains the field
        if self.ro_sub2c is None and "ro_sub2c" in self.model_fields_set:
            _dict['roSub2c'] = None

        # set to None if ro_sub2d (nullable) is None
        # and model_fields_set contains the field
        if self.ro_sub2d is None and "ro_sub2d" in self.model_fields_set:
            _dict['roSub2d'] = None

        # set to None if ro_sub3 (nullable) is None
        # and model_fields_set contains the field
        if self.ro_sub3 is None and "ro_sub3" in self.model_fields_set:
            _dict['roSub3'] = None

        # set to None if ro_sub3b (nullable) is None
        # and model_fields_set contains the field
        if self.ro_sub3b is None and "ro_sub3b" in self.model_fields_set:
            _dict['roSub3b'] = None

        # set to None if ro_sub3c (nullable) is None
        # and model_fields_set contains the field
        if self.ro_sub3c is None and "ro_sub3c" in self.model_fields_set:
            _dict['roSub3c'] = None

        # set to None if ro_sub3d (nullable) is None
        # and model_fields_set contains the field
        if self.ro_sub3d is None and "ro_sub3d" in self.model_fields_set:
            _dict['roSub3d'] = None

        # set to None if ro_sub4 (nullable) is None
        # and model_fields_set contains the field
        if self.ro_sub4 is None and "ro_sub4" in self.model_fields_set:
            _dict['roSub4'] = None

        # set to None if ro_sub4b (nullable) is None
        # and model_fields_set contains the field
        if self.ro_sub4b is None and "ro_sub4b" in self.model_fields_set:
            _dict['roSub4b'] = None

        # set to None if ro_sub4c (nullable) is None
        # and model_fields_set contains the field
        if self.ro_sub4c is None and "ro_sub4c" in self.model_fields_set:
            _dict['roSub4c'] = None

        # set to None if ro_sub4d (nullable) is None
        # and model_fields_set contains the field
        if self.ro_sub4d is None and "ro_sub4d" in self.model_fields_set:
            _dict['roSub4d'] = None

        # set to None if ro_sub5 (nullable) is None
        # and model_fields_set contains the field
        if self.ro_sub5 is None and "ro_sub5" in self.model_fields_set:
            _dict['roSub5'] = None

        # set to None if ro_sub5b (nullable) is None
        # and model_fields_set contains the field
        if self.ro_sub5b is None and "ro_sub5b" in self.model_fields_set:
            _dict['roSub5b'] = None

        # set to None if ro_sub5c (nullable) is None
        # and model_fields_set contains the field
        if self.ro_sub5c is None and "ro_sub5c" in self.model_fields_set:
            _dict['roSub5c'] = None

        # set to None if ro_sub5d (nullable) is None
        # and model_fields_set contains the field
        if self.ro_sub5d is None and "ro_sub5d" in self.model_fields_set:
            _dict['roSub5d'] = None

        # set to None if ro_tite1 (nullable) is None
        # and model_fields_set contains the field
        if self.ro_tite1 is None and "ro_tite1" in self.model_fields_set:
            _dict['roTite1'] = None

        # set to None if ro_tite1b (nullable) is None
        # and model_fields_set contains the field
        if self.ro_tite1b is None and "ro_tite1b" in self.model_fields_set:
            _dict['roTite1b'] = None

        # set to None if ro_tite1c (nullable) is None
        # and model_fields_set contains the field
        if self.ro_tite1c is None and "ro_tite1c" in self.model_fields_set:
            _dict['roTite1c'] = None

        # set to None if ro_tite1d (nullable) is None
        # and model_fields_set contains the field
        if self.ro_tite1d is None and "ro_tite1d" in self.model_fields_set:
            _dict['roTite1d'] = None

        # set to None if ro_tite2 (nullable) is None
        # and model_fields_set contains the field
        if self.ro_tite2 is None and "ro_tite2" in self.model_fields_set:
            _dict['roTite2'] = None

        # set to None if ro_tite2b (nullable) is None
        # and model_fields_set contains the field
        if self.ro_tite2b is None and "ro_tite2b" in self.model_fields_set:
            _dict['roTite2b'] = None

        # set to None if ro_tite2c (nullable) is None
        # and model_fields_set contains the field
        if self.ro_tite2c is None and "ro_tite2c" in self.model_fields_set:
            _dict['roTite2c'] = None

        # set to None if ro_tite2d (nullable) is None
        # and model_fields_set contains the field
        if self.ro_tite2d is None and "ro_tite2d" in self.model_fields_set:
            _dict['roTite2d'] = None

        # set to None if ro_tite3 (nullable) is None
        # and model_fields_set contains the field
        if self.ro_tite3 is None and "ro_tite3" in self.model_fields_set:
            _dict['roTite3'] = None

        # set to None if ro_tite3b (nullable) is None
        # and model_fields_set contains the field
        if self.ro_tite3b is None and "ro_tite3b" in self.model_fields_set:
            _dict['roTite3b'] = None

        # set to None if ro_tite3c (nullable) is None
        # and model_fields_set contains the field
        if self.ro_tite3c is None and "ro_tite3c" in self.model_fields_set:
            _dict['roTite3c'] = None

        # set to None if ro_tite3d (nullable) is None
        # and model_fields_set contains the field
        if self.ro_tite3d is None and "ro_tite3d" in self.model_fields_set:
            _dict['roTite3d'] = None

        # set to None if ro_tite4 (nullable) is None
        # and model_fields_set contains the field
        if self.ro_tite4 is None and "ro_tite4" in self.model_fields_set:
            _dict['roTite4'] = None

        # set to None if ro_tite4b (nullable) is None
        # and model_fields_set contains the field
        if self.ro_tite4b is None and "ro_tite4b" in self.model_fields_set:
            _dict['roTite4b'] = None

        # set to None if ro_tite4c (nullable) is None
        # and model_fields_set contains the field
        if self.ro_tite4c is None and "ro_tite4c" in self.model_fields_set:
            _dict['roTite4c'] = None

        # set to None if ro_tite4d (nullable) is None
        # and model_fields_set contains the field
        if self.ro_tite4d is None and "ro_tite4d" in self.model_fields_set:
            _dict['roTite4d'] = None

        # set to None if ro_tite5 (nullable) is None
        # and model_fields_set contains the field
        if self.ro_tite5 is None and "ro_tite5" in self.model_fields_set:
            _dict['roTite5'] = None

        # set to None if ro_tite5b (nullable) is None
        # and model_fields_set contains the field
        if self.ro_tite5b is None and "ro_tite5b" in self.model_fields_set:
            _dict['roTite5b'] = None

        # set to None if ro_tite5c (nullable) is None
        # and model_fields_set contains the field
        if self.ro_tite5c is None and "ro_tite5c" in self.model_fields_set:
            _dict['roTite5c'] = None

        # set to None if ro_tite5d (nullable) is None
        # and model_fields_set contains the field
        if self.ro_tite5d is None and "ro_tite5d" in self.model_fields_set:
            _dict['roTite5d'] = None

        # set to None if ro_tube1 (nullable) is None
        # and model_fields_set contains the field
        if self.ro_tube1 is None and "ro_tube1" in self.model_fields_set:
            _dict['roTube1'] = None

        # set to None if ro_tube2 (nullable) is None
        # and model_fields_set contains the field
        if self.ro_tube2 is None and "ro_tube2" in self.model_fields_set:
            _dict['roTube2'] = None

        # set to None if ro_tube3 (nullable) is None
        # and model_fields_set contains the field
        if self.ro_tube3 is None and "ro_tube3" in self.model_fields_set:
            _dict['roTube3'] = None

        # set to None if ro_tube4 (nullable) is None
        # and model_fields_set contains the field
        if self.ro_tube4 is None and "ro_tube4" in self.model_fields_set:
            _dict['roTube4'] = None

        # set to None if ro_tube5 (nullable) is None
        # and model_fields_set contains the field
        if self.ro_tube5 is None and "ro_tube5" in self.model_fields_set:
            _dict['roTube5'] = None

        # set to None if ro_vol1 (nullable) is None
        # and model_fields_set contains the field
        if self.ro_vol1 is None and "ro_vol1" in self.model_fields_set:
            _dict['roVol1'] = None

        # set to None if ro_vol2 (nullable) is None
        # and model_fields_set contains the field
        if self.ro_vol2 is None and "ro_vol2" in self.model_fields_set:
            _dict['roVol2'] = None

        # set to None if ro_vol3 (nullable) is None
        # and model_fields_set contains the field
        if self.ro_vol3 is None and "ro_vol3" in self.model_fields_set:
            _dict['roVol3'] = None

        # set to None if ro_vol4 (nullable) is None
        # and model_fields_set contains the field
        if self.ro_vol4 is None and "ro_vol4" in self.model_fields_set:
            _dict['roVol4'] = None

        # set to None if ro_vol5 (nullable) is None
        # and model_fields_set contains the field
        if self.ro_vol5 is None and "ro_vol5" in self.model_fields_set:
            _dict['roVol5'] = None

        # set to None if ro_vol_v1 (nullable) is None
        # and model_fields_set contains the field
        if self.ro_vol_v1 is None and "ro_vol_v1" in self.model_fields_set:
            _dict['roVolV1'] = None

        # set to None if ro_vol_v1b (nullable) is None
        # and model_fields_set contains the field
        if self.ro_vol_v1b is None and "ro_vol_v1b" in self.model_fields_set:
            _dict['roVolV1b'] = None

        # set to None if ro_vol_v1c (nullable) is None
        # and model_fields_set contains the field
        if self.ro_vol_v1c is None and "ro_vol_v1c" in self.model_fields_set:
            _dict['roVolV1c'] = None

        # set to None if ro_vol_v1d (nullable) is None
        # and model_fields_set contains the field
        if self.ro_vol_v1d is None and "ro_vol_v1d" in self.model_fields_set:
            _dict['roVolV1d'] = None

        # set to None if ro_vol_v2 (nullable) is None
        # and model_fields_set contains the field
        if self.ro_vol_v2 is None and "ro_vol_v2" in self.model_fields_set:
            _dict['roVolV2'] = None

        # set to None if ro_vol_v2b (nullable) is None
        # and model_fields_set contains the field
        if self.ro_vol_v2b is None and "ro_vol_v2b" in self.model_fields_set:
            _dict['roVolV2b'] = None

        # set to None if ro_vol_v2c (nullable) is None
        # and model_fields_set contains the field
        if self.ro_vol_v2c is None and "ro_vol_v2c" in self.model_fields_set:
            _dict['roVolV2c'] = None

        # set to None if ro_vol_v2d (nullable) is None
        # and model_fields_set contains the field
        if self.ro_vol_v2d is None and "ro_vol_v2d" in self.model_fields_set:
            _dict['roVolV2d'] = None

        # set to None if ro_vol_v3 (nullable) is None
        # and model_fields_set contains the field
        if self.ro_vol_v3 is None and "ro_vol_v3" in self.model_fields_set:
            _dict['roVolV3'] = None

        # set to None if ro_vol_v3b (nullable) is None
        # and model_fields_set contains the field
        if self.ro_vol_v3b is None and "ro_vol_v3b" in self.model_fields_set:
            _dict['roVolV3b'] = None

        # set to None if ro_vol_v3c (nullable) is None
        # and model_fields_set contains the field
        if self.ro_vol_v3c is None and "ro_vol_v3c" in self.model_fields_set:
            _dict['roVolV3c'] = None

        # set to None if ro_vol_v3d (nullable) is None
        # and model_fields_set contains the field
        if self.ro_vol_v3d is None and "ro_vol_v3d" in self.model_fields_set:
            _dict['roVolV3d'] = None

        # set to None if ro_vol_v4 (nullable) is None
        # and model_fields_set contains the field
        if self.ro_vol_v4 is None and "ro_vol_v4" in self.model_fields_set:
            _dict['roVolV4'] = None

        # set to None if ro_vol_v4b (nullable) is None
        # and model_fields_set contains the field
        if self.ro_vol_v4b is None and "ro_vol_v4b" in self.model_fields_set:
            _dict['roVolV4b'] = None

        # set to None if ro_vol_v4c (nullable) is None
        # and model_fields_set contains the field
        if self.ro_vol_v4c is None and "ro_vol_v4c" in self.model_fields_set:
            _dict['roVolV4c'] = None

        # set to None if ro_vol_v4d (nullable) is None
        # and model_fields_set contains the field
        if self.ro_vol_v4d is None and "ro_vol_v4d" in self.model_fields_set:
            _dict['roVolV4d'] = None

        # set to None if ro_vol_v5 (nullable) is None
        # and model_fields_set contains the field
        if self.ro_vol_v5 is None and "ro_vol_v5" in self.model_fields_set:
            _dict['roVolV5'] = None

        # set to None if ro_vol_v5b (nullable) is None
        # and model_fields_set contains the field
        if self.ro_vol_v5b is None and "ro_vol_v5b" in self.model_fields_set:
            _dict['roVolV5b'] = None

        # set to None if ro_vol_v5c (nullable) is None
        # and model_fields_set contains the field
        if self.ro_vol_v5c is None and "ro_vol_v5c" in self.model_fields_set:
            _dict['roVolV5c'] = None

        # set to None if ro_vol_v5d (nullable) is None
        # and model_fields_set contains the field
        if self.ro_vol_v5d is None and "ro_vol_v5d" in self.model_fields_set:
            _dict['roVolV5d'] = None

        # set to None if sign_x002d_off_x0020_status (nullable) is None
        # and model_fields_set contains the field
        if self.sign_x002d_off_x0020_status is None and "sign_x002d_off_x0020_status" in self.model_fields_set:
            _dict['Sign_x002d_off_x0020_status'] = None

        # set to None if spec_deli_loc (nullable) is None
        # and model_fields_set contains the field
        if self.spec_deli_loc is None and "spec_deli_loc" in self.model_fields_set:
            _dict['SpecDeliLoc'] = None

        # set to None if tam (nullable) is None
        # and model_fields_set contains the field
        if self.tam is None and "tam" in self.model_fields_set:
            _dict['TAM'] = None

        # set to None if tam_age (nullable) is None
        # and model_fields_set contains the field
        if self.tam_age is None and "tam_age" in self.model_fields_set:
            _dict['TAMAge'] = None

        # set to None if tc_prep (nullable) is None
        # and model_fields_set contains the field
        if self.tc_prep is None and "tc_prep" in self.model_fields_set:
            _dict['TCPrep'] = None

        # set to None if tc_tiss (nullable) is None
        # and model_fields_set contains the field
        if self.tc_tiss is None and "tc_tiss" in self.model_fields_set:
            _dict['TCTiss'] = None

        # set to None if title (nullable) is None
        # and model_fields_set contains the field
        if self.title is None and "title" in self.model_fields_set:
            _dict['Title'] = None

        # set to None if tmp (nullable) is None
        # and model_fields_set contains the field
        if self.tmp is None and "tmp" in self.model_fields_set:
            _dict['TMP'] = None

        # set to None if tmp_age (nullable) is None
        # and model_fields_set contains the field
        if self.tmp_age is None and "tmp_age" in self.model_fields_set:
            _dict['TMPAge'] = None

        # set to None if ui_version_string (nullable) is None
        # and model_fields_set contains the field
        if self.ui_version_string is None and "ui_version_string" in self.model_fields_set:
            _dict['_UIVersionString'] = None

        # set to None if wellness_report_x0028_no_x002_f_ye (nullable) is None
        # and model_fields_set contains the field
        if self.wellness_report_x0028_no_x002_f_ye is None and "wellness_report_x0028_no_x002_f_ye" in self.model_fields_set:
            _dict['WellnessReport_x0028_No_x002F_Ye'] = None

        # set to None if author_id (nullable) is None
        # and model_fields_set contains the field
        if self.author_id is None and "author_id" in self.model_fields_set:
            _dict['AuthorId'] = None

        # set to None if author_lookup_id (nullable) is None
        # and model_fields_set contains the field
        if self.author_lookup_id is None and "author_lookup_id" in self.model_fields_set:
            _dict['AuthorLookupId'] = None

        # set to None if editor_id (nullable) is None
        # and model_fields_set contains the field
        if self.editor_id is None and "editor_id" in self.model_fields_set:
            _dict['EditorId'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Las2020List from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "AccommodationComment": obj.get("AccommodationComment"),
            "ACSFTime1": obj.get("ACSFTime1"),
            "ACSFTime2": obj.get("ACSFTime2"),
            "ACSFTime3": obj.get("ACSFTime3"),
            "ACSFTime4": obj.get("ACSFTime4"),
            "ACSFTime5": obj.get("ACSFTime5"),
            "ACSFID1": obj.get("ACSFID1"),
            "ACSFID2": obj.get("ACSFID2"),
            "ACSFID3": obj.get("ACSFID3"),
            "ACSFID4": obj.get("ACSFID4"),
            "ACSFID5": obj.get("ACSFID5"),
            "AfternoonPF": obj.get("AfternoonPF"),
            "AnimalsAvailableonProtocol": obj.get("AnimalsAvailableonProtocol"),
            "AppAuthor": obj.get("AppAuthor"),
            "AppEditor": obj.get("AppEditor"),
            "Attachments": obj.get("Attachments"),
            "Author": obj.get("Author"),
            "BCAge": obj.get("BCAge"),
            "BCGenotypes": obj.get("BCGenotypes"),
            "BCLocation": obj.get("BCLocation"),
            "BCTube": obj.get("BCTube"),
            "BCType": obj.get("BCType"),
            "BCVolume": obj.get("BCVolume"),
            "_ColorTag": obj.get("_ColorTag"),
            "ComplianceAssetId": obj.get("ComplianceAssetId"),
            "_ComplianceFlags": obj.get("_ComplianceFlags"),
            "_ComplianceTag": obj.get("_ComplianceTag"),
            "_ComplianceTagUserId": obj.get("_ComplianceTagUserId"),
            "_ComplianceTagWrittenTime": obj.get("_ComplianceTagWrittenTime"),
            "ContentType": obj.get("ContentType"),
            "Created": obj.get("Created"),
            "custcontact": obj.get("custcontact"),
            "CustomCom1": obj.get("CustomCom1"),
            "CustomCom2": obj.get("CustomCom2"),
            "custpresent": obj.get("custpresent"),
            "DeliveryLocation": obj.get("DeliveryLocation"),
            "DocIcon": obj.get("DocIcon"),
            "doseRoute": obj.get("doseRoute"),
            "doseSub": obj.get("doseSub"),
            "doseWhere": obj.get("doseWhere"),
            "doseduration": obj.get("doseduration"),
            "dosevolume": obj.get("dosevolume"),
            "Doxycycline": obj.get("Doxycycline"),
            "Edit": obj.get("Edit"),
            "Editor": obj.get("Editor"),
            "FolderChildCount": obj.get("FolderChildCount"),
            "icvComment": obj.get("icvComment"),
            "icvID1": obj.get("icvID1"),
            "icvID2": obj.get("icvID2"),
            "icvID3": obj.get("icvID3"),
            "icvID4": obj.get("icvID4"),
            "icvID5": obj.get("icvID5"),
            "icvLIMS": obj.get("icvLIMS"),
            "icvRoute1": obj.get("icvRoute1"),
            "icvRoute2": obj.get("icvRoute2"),
            "icvRoute3": obj.get("icvRoute3"),
            "icvRoute4": obj.get("icvRoute4"),
            "icvRoute5": obj.get("icvRoute5"),
            "icvSub1": obj.get("icvSub1"),
            "icvSub2": obj.get("icvSub2"),
            "icvSub3": obj.get("icvSub3"),
            "icvSub4": obj.get("icvSub4"),
            "icvSub5": obj.get("icvSub5"),
            "ID": obj.get("ID"),
            "_IsRecord": obj.get("_IsRecord"),
            "ItemChildCount": obj.get("ItemChildCount"),
            "LTaID1": obj.get("LTaID1"),
            "LTaID2": obj.get("LTaID2"),
            "LTaID3": obj.get("LTaID3"),
            "LTaID4": obj.get("LTaID4"),
            "LTaID5": obj.get("LTaID5"),
            "LTdate1": obj.get("LTdate1"),
            "LTdate2": obj.get("LTdate2"),
            "LTdate3": obj.get("LTdate3"),
            "LTdate4": obj.get("LTdate4"),
            "LTdate5": obj.get("LTdate5"),
            "LASComments": obj.get("LASComments"),
            "LIMSEntry": obj.get("LIMSEntry"),
            "LIMSProject": obj.get("LIMSProject"),
            "LIMSWorkflow": obj.get("LIMSWorkflow"),
            "LIMSWorkflow_x0020_2": obj.get("LIMSWorkflow_x0020_2"),
            "LinkTitle": obj.get("LinkTitle"),
            "LinkTitleNoMenu": obj.get("LinkTitleNoMenu"),
            "LTTask1": obj.get("LTTask1"),
            "LTTask2": obj.get("LTTask2"),
            "LTTask3": obj.get("LTTask3"),
            "LTTask4": obj.get("LTTask4"),
            "LTTask5": obj.get("LTTask5"),
            "Modified": obj.get("Modified"),
            "nEnd_x0020_Date": obj.get("nEnd_x0020_Date"),
            "nROID1": obj.get("nROID1"),
            "nROID2": obj.get("nROID2"),
            "nROID3": obj.get("nROID3"),
            "nROID4": obj.get("nROID4"),
            "nROID5": obj.get("nROID5"),
            "nStart_x0020_Date": obj.get("nStart_x0020_Date"),
            "OCT": obj.get("OCT"),
            "PostFix": obj.get("PostFix"),
            "ProjectID": obj.get("ProjectID"),
            "ProjectLead2": obj.get("ProjectLead2"),
            "Protocol": obj.get("Protocol"),
            "QCDoorSheet": obj.get("QCDoorSheet"),
            "ReqAge1": obj.get("ReqAge1"),
            "ReqAge2": obj.get("ReqAge2"),
            "ReqAge3": obj.get("ReqAge3"),
            "ReqAge4": obj.get("ReqAge4"),
            "ReqPro1": obj.get("ReqPro1"),
            "ReqPro2": obj.get("ReqPro2"),
            "ReqPro3": obj.get("ReqPro3"),
            "ReqPro4": obj.get("ReqPro4"),
            "Reqdate1": obj.get("Reqdate1"),
            "Reqdate2": obj.get("Reqdate2"),
            "Reqdate3": obj.get("Reqdate3"),
            "Reqdate4": obj.get("Reqdate4"),
            "RequestStatus2": obj.get("RequestStatus2"),
            "roBox1": obj.get("roBox1"),
            "roBox2": obj.get("roBox2"),
            "roBox3": obj.get("roBox3"),
            "roBox4": obj.get("roBox4"),
            "roBox5": obj.get("roBox5"),
            "roComment": obj.get("roComment"),
            "roDiscard": obj.get("roDiscard"),
            "roEye1": obj.get("roEye1"),
            "roEye2": obj.get("roEye2"),
            "roEye3": obj.get("roEye3"),
            "roEye4": obj.get("roEye4"),
            "roEye5": obj.get("roEye5"),
            "roGC1": obj.get("roGC1"),
            "roGC1b": obj.get("roGC1b"),
            "roGC1c": obj.get("roGC1c"),
            "roGC1d": obj.get("roGC1d"),
            "roGC2": obj.get("roGC2"),
            "roGC2b": obj.get("roGC2b"),
            "roGC2c": obj.get("roGC2c"),
            "roGC2d": obj.get("roGC2d"),
            "roGC3": obj.get("roGC3"),
            "roGC3b": obj.get("roGC3b"),
            "roGC3c": obj.get("roGC3c"),
            "roGC3d": obj.get("roGC3d"),
            "roGC4": obj.get("roGC4"),
            "roGC4b": obj.get("roGC4b"),
            "roGC4c": obj.get("roGC4c"),
            "roGC4d": obj.get("roGC4d"),
            "roGC5": obj.get("roGC5"),
            "roGC5b": obj.get("roGC5b"),
            "roGC5c": obj.get("roGC5c"),
            "roGC5d": obj.get("roGC5d"),
            "roIce": obj.get("roIce"),
            "roLIMS": obj.get("roLIMS"),
            "roLot1": obj.get("roLot1"),
            "roLot1b": obj.get("roLot1b"),
            "roLot1c": obj.get("roLot1c"),
            "roLot1d": obj.get("roLot1d"),
            "roLot2": obj.get("roLot2"),
            "roLot2b": obj.get("roLot2b"),
            "roLot2c": obj.get("roLot2c"),
            "roLot2d": obj.get("roLot2d"),
            "roLot3": obj.get("roLot3"),
            "roLot3b": obj.get("roLot3b"),
            "roLot3c": obj.get("roLot3c"),
            "roLot3d": obj.get("roLot3d"),
            "roLot4": obj.get("roLot4"),
            "roLot4b": obj.get("roLot4b"),
            "roLot4c": obj.get("roLot4c"),
            "roLot4d": obj.get("roLot4d"),
            "roLot5": obj.get("roLot5"),
            "roLot5b": obj.get("roLot5b"),
            "roLot5c": obj.get("roLot5c"),
            "roLot5d": obj.get("roLot5d"),
            "roSOP": obj.get("roSOP"),
            "roSpinDown": obj.get("roSpinDown"),
            "roSub1": obj.get("roSub1"),
            "roSub1b": obj.get("roSub1b"),
            "roSub1c": obj.get("roSub1c"),
            "roSub1d": obj.get("roSub1d"),
            "roSub2": obj.get("roSub2"),
            "roSub2b": obj.get("roSub2b"),
            "roSub2c": obj.get("roSub2c"),
            "roSub2d": obj.get("roSub2d"),
            "roSub3": obj.get("roSub3"),
            "roSub3b": obj.get("roSub3b"),
            "roSub3c": obj.get("roSub3c"),
            "roSub3d": obj.get("roSub3d"),
            "roSub4": obj.get("roSub4"),
            "roSub4b": obj.get("roSub4b"),
            "roSub4c": obj.get("roSub4c"),
            "roSub4d": obj.get("roSub4d"),
            "roSub5": obj.get("roSub5"),
            "roSub5b": obj.get("roSub5b"),
            "roSub5c": obj.get("roSub5c"),
            "roSub5d": obj.get("roSub5d"),
            "roTite1": obj.get("roTite1"),
            "roTite1b": obj.get("roTite1b"),
            "roTite1c": obj.get("roTite1c"),
            "roTite1d": obj.get("roTite1d"),
            "roTite2": obj.get("roTite2"),
            "roTite2b": obj.get("roTite2b"),
            "roTite2c": obj.get("roTite2c"),
            "roTite2d": obj.get("roTite2d"),
            "roTite3": obj.get("roTite3"),
            "roTite3b": obj.get("roTite3b"),
            "roTite3c": obj.get("roTite3c"),
            "roTite3d": obj.get("roTite3d"),
            "roTite4": obj.get("roTite4"),
            "roTite4b": obj.get("roTite4b"),
            "roTite4c": obj.get("roTite4c"),
            "roTite4d": obj.get("roTite4d"),
            "roTite5": obj.get("roTite5"),
            "roTite5b": obj.get("roTite5b"),
            "roTite5c": obj.get("roTite5c"),
            "roTite5d": obj.get("roTite5d"),
            "roTube1": obj.get("roTube1"),
            "roTube2": obj.get("roTube2"),
            "roTube3": obj.get("roTube3"),
            "roTube4": obj.get("roTube4"),
            "roTube5": obj.get("roTube5"),
            "roVol1": obj.get("roVol1"),
            "roVol2": obj.get("roVol2"),
            "roVol3": obj.get("roVol3"),
            "roVol4": obj.get("roVol4"),
            "roVol5": obj.get("roVol5"),
            "roVolV1": obj.get("roVolV1"),
            "roVolV1b": obj.get("roVolV1b"),
            "roVolV1c": obj.get("roVolV1c"),
            "roVolV1d": obj.get("roVolV1d"),
            "roVolV2": obj.get("roVolV2"),
            "roVolV2b": obj.get("roVolV2b"),
            "roVolV2c": obj.get("roVolV2c"),
            "roVolV2d": obj.get("roVolV2d"),
            "roVolV3": obj.get("roVolV3"),
            "roVolV3b": obj.get("roVolV3b"),
            "roVolV3c": obj.get("roVolV3c"),
            "roVolV3d": obj.get("roVolV3d"),
            "roVolV4": obj.get("roVolV4"),
            "roVolV4b": obj.get("roVolV4b"),
            "roVolV4c": obj.get("roVolV4c"),
            "roVolV4d": obj.get("roVolV4d"),
            "roVolV5": obj.get("roVolV5"),
            "roVolV5b": obj.get("roVolV5b"),
            "roVolV5c": obj.get("roVolV5c"),
            "roVolV5d": obj.get("roVolV5d"),
            "roWhere": obj.get("roWhere"),
            "Sign_x002d_off_x0020_status": obj.get("Sign_x002d_off_x0020_status"),
            "SpecDeliLoc": obj.get("SpecDeliLoc"),
            "Species": obj.get("Species"),
            "TAM": obj.get("TAM"),
            "TAMAge": obj.get("TAMAge"),
            "TAMFreq": obj.get("TAMFreq"),
            "TCPrep": obj.get("TCPrep"),
            "TCTiss": obj.get("TCTiss"),
            "Title": obj.get("Title"),
            "TMP": obj.get("TMP"),
            "TMPAge": obj.get("TMPAge"),
            "TMPFreq": obj.get("TMPFreq"),
            "_UIVersionString": obj.get("_UIVersionString"),
            "WellnessReport_x0028_No_x002F_Ye": obj.get("WellnessReport_x0028_No_x002F_Ye"),
            "WheretoObtainsubstance_x0028_ICV": obj.get("WheretoObtainsubstance_x0028_ICV"),
            "AuthorId": obj.get("AuthorId"),
            "AuthorLookupId": obj.get("AuthorLookupId"),
            "EditorId": obj.get("EditorId")
        })
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj





# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class LASDeliverylocation(str, Enum):
    """
    Enum class for DeliveryLocation.
    """

    """
    allowed enum values
    """
    N_156_4C = '156 4c'
    N_139_80 = '139 -80'
    N_220_4C_IM = '220 4c(IM)'
    N_270_4C = '270 4c'
    N_270_80_B_SHELF_3_LEFT = '270 -80B Shelf 3 (Left)'
    N_320_AIND_4C = '320 AIND 4c'
    N_320_80_SHELF_6 = '320 -80 Shelf 6'
    N_340_4C = '340 4c'
    N_340_80_B_SHELF_1 = '340 -80B Shelf 1'
    N_370_WALK_IN_4C = '370 Walk-in 4c'
    N_379_20_A_SHELF_2 = '379 -20A Shelf 2'
    N_373_80_A_SHELF_2 = '373 -80A Shelf 2'
    N_420_4C = '420 4c'
    N_440_4C = '440 4c'
    N_470_4C = '470 4c'
    N_473_80_E_SHELF_3 = '473 -80E Shelf 3'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of LASDeliverylocation from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class NSB2023Burr6IntendedCcfTarget(str, Enum):
    """
    Enum class for Burr 6 Intended CCF Target.
    """

    """
    allowed enum values
    """
    SELECT = 'Select...'
    FRP__FRONTAL_POLE_CEREBRA = 'FRP - Frontal pole cerebral cortex'
    M_OP__PRIMARY_MOTOR_AREA = 'MOp - Primary motor area'
    M_OS__SECONDARY_MOTOR_ARE = 'MOs - Secondary motor area'
    S_SP_N__PRIMARY_SOMATOSEN = 'SSp-n - Primary somatosensory area nose'
    S_SP_BFD__PRIMARY_SOMATOS = 'SSp-bfd - Primary somatosensory area barrel field'
    S_SP_LL__PRIMARY_SOMATOSE = 'SSp-ll - Primary somatosensory area lower limb'
    S_SP_M__PRIMARY_SOMATOSEN = 'SSp-m - Primary somatosensory area mouth'
    S_SP_UL__PRIMARY_SOMATOSE = 'SSp-ul - Primary somatosensory area upper limb'
    S_SP_TR__PRIMARY_SOMATOSE = 'SSp-tr - Primary somatosensory area trunk'
    S_SP_UN__PRIMARY_SOMATOSE = 'SSp-un - Primary somatosensory area unassigned'
    S_SS__SUPPLEMENTAL_SOMATO = 'SSs - Supplemental somatosensory area'
    GU__GUSTATORY_AREAS = 'GU - Gustatory areas'
    VISC__VISCERAL_AREA = 'VISC - Visceral area'
    AU_DD__DORSAL_AUDITORY_AR = 'AUDd - Dorsal auditory area'
    AU_DP__PRIMARY_AUDITORY_A = 'AUDp - Primary auditory area'
    AU_DPO__POSTERIOR_AUDITOR = 'AUDpo - Posterior auditory area'
    AU_DV__VENTRAL_AUDITORY_A = 'AUDv - Ventral auditory area'
    VI_SAL__ANTEROLATERAL_VIS = 'VISal - Anterolateral visual area'
    VI_SAM__ANTEROMEDIAL_VISU = 'VISam - Anteromedial visual area'
    VI_SL__LATERAL_VISUAL_ARE = 'VISl - Lateral visual area'
    VI_SP__PRIMARY_VISUAL_ARE = 'VISp - Primary visual area'
    VI_SPL__POSTEROLATERAL_VI = 'VISpl - Posterolateral visual area'
    VI_SPM_POSTEROMEDIAL_VISU = 'VISpm - posteromedial visual area'
    VI_SLI__LATEROINTERMEDIAT = 'VISli - Laterointermediate area'
    VI_SPOR__POSTRHINAL_AREA = 'VISpor - Postrhinal area'
    AC_AD__ANTERIOR_CINGULATE = 'ACAd - Anterior cingulate area dorsal part'
    AC_AV__ANTERIOR_CINGULATE = 'ACAv - Anterior cingulate area ventral part'
    PL__PRELIMBIC_AREA = 'PL - Prelimbic area'
    ILA__INFRALIMBIC_AREA = 'ILA - Infralimbic area'
    OR_BL__ORBITAL_AREA_LATER = 'ORBl - Orbital area lateral part'
    OR_BM__ORBITAL_AREA_MEDIA = 'ORBm - Orbital area medial part'
    OR_BV__ORBITAL_AREA_VENTR = 'ORBv - Orbital area ventral part'
    OR_BVL__ORBITAL_AREA_VENT = 'ORBvl - Orbital area ventrolateral part'
    A_ID__AGRANULAR_INSULAR_A = 'AId - Agranular insular area dorsal part'
    A_IP__AGRANULAR_INSULAR_A = 'AIp - Agranular insular area posterior part'
    A_IV__AGRANULAR_INSULAR_A = 'AIv - Agranular insular area ventral part'
    RS_PAGL__RETROSPLENIAL_AR = 'RSPagl - Retrosplenial area lateral agranular part'
    RS_PD__RETROSPLENIAL_AREA = 'RSPd - Retrosplenial area dorsal part'
    RS_PV__RETROSPLENIAL_AREA = 'RSPv - Retrosplenial area ventral part'
    VI_SA__ANTERIOR_AREA = 'VISa - Anterior area'
    VI_SRL__ROSTROLATERAL_VIS = 'VISrl - Rostrolateral visual area'
    T_EA__TEMPORAL_ASSOCIATIO = 'TEa - Temporal association areas'
    PERI__PERIRHINAL_AREA = 'PERI - Perirhinal area'
    ECT__ECTORHINAL_AREA = 'ECT - Ectorhinal area'
    MOB__MAIN_OLFACTORY_BULB = 'MOB - Main olfactory bulb'
    AOB__ACCESSORY_OLFACTORY = 'AOB - Accessory olfactory bulb'
    AON__ANTERIOR_OLFACTORY_N = 'AON - Anterior olfactory nucleus'
    T_TD__TAENIA_TECTA_DORSAL = 'TTd - Taenia tecta dorsal part'
    T_TV__TAENIA_TECTA_VENTRA = 'TTv - Taenia tecta ventral part'
    DP__DORSAL_PEDUNCULAR_ARE = 'DP - Dorsal peduncular area'
    PIR__PIRIFORM_AREA = 'PIR - Piriform area'
    NLOT__NUCLEUS_OF_THE_LATE = 'NLOT - Nucleus of the lateral olfactory tract'
    CO_AA__CORTICAL_AMYGDALAR = 'COAa - Cortical amygdalar area anterior part'
    CO_AP__CORTICAL_AMYGDALAR = 'COAp - Cortical amygdalar area posterior part'
    PAA__PIRIFORM_AMYGDALAR_A = 'PAA - Piriform-amygdalar area'
    TR__POSTPIRIFORM_TRANSITI = 'TR - Postpiriform transition area'
    CA1__FIELD_CA1 = 'CA1 - Field CA1'
    CA2__FIELD_CA2 = 'CA2 - Field CA2'
    CA3__FIELD_CA3 = 'CA3 - Field CA3'
    DG__DENTATE_GYRUS = 'DG - Dentate gyrus'
    FC__FASCIOLA_CINEREA = 'FC - Fasciola cinerea'
    IG__INDUSEUM_GRISEUM = 'IG - Induseum griseum'
    EN_TL__ENTORHINAL_AREA_LA = 'ENTl - Entorhinal area lateral part'
    EN_TM__ENTORHINAL_AREA_ME = 'ENTm - Entorhinal area medial part dorsal zone'
    PAR__PARASUBICULUM = 'PAR - Parasubiculum'
    POST__POSTSUBICULUM = 'POST - Postsubiculum'
    PRE__PRESUBICULUM = 'PRE - Presubiculum'
    SUB__SUBICULUM = 'SUB - Subiculum'
    PRO_S__PROSUBICULUM = 'ProS - Prosubiculum'
    HATA__HIPPOCAMPO_AMYGDALA = 'HATA - Hippocampo-amygdalar transition area'
    A_PR__AREA_PROSTRIATA = 'APr - Area prostriata'
    CLA__CLAUSTRUM = 'CLA - Claustrum'
    E_PD__ENDOPIRIFORM_NUCLEU = 'EPd - Endopiriform nucleus dorsal part'
    E_PV__ENDOPIRIFORM_NUCLEU = 'EPv - Endopiriform nucleus ventral part'
    LA__LATERAL_AMYGDALAR_NUC = 'LA - Lateral amygdalar nucleus'
    BLA__BASOLATERAL_AMYGDALA = 'BLA - Basolateral amygdalar nucleus'
    BMA__BASOMEDIAL_AMYGDALAR = 'BMA - Basomedial amygdalar nucleus'
    PA__POSTERIOR_AMYGDALAR_N = 'PA - Posterior amygdalar nucleus'
    CP__CAUDOPUTAMEN = 'CP - Caudoputamen'
    ACB__NUCLEUS_ACCUMBENS = 'ACB - Nucleus accumbens'
    FS__FUNDUS_OF_STRIATUM = 'FS - Fundus of striatum'
    OT__OLFACTORY_TUBERCLE = 'OT - Olfactory tubercle'
    L_SC__LATERAL_SEPTAL_NUCL = 'LSc - Lateral septal nucleus caudal (caudodorsal) part'
    L_SR__LATERAL_SEPTAL_NUCL = 'LSr - Lateral septal nucleus rostral (rostroventral) part'
    L_SV__LATERAL_SEPTAL_NUCL = 'LSv - Lateral septal nucleus ventral part'
    SF__SEPTOFIMBRIAL_NUCLEUS = 'SF - Septofimbrial nucleus'
    SH__SEPTOHIPPOCAMPAL_NUCL = 'SH - Septohippocampal nucleus'
    AAA__ANTERIOR_AMYGDALAR_A = 'AAA - Anterior amygdalar area'
    BA__BED_NUCLEUS_OF_THE_AC = 'BA - Bed nucleus of the accessory olfactory tract'
    CEA__CENTRAL_AMYGDALAR_NU = 'CEA - Central amygdalar nucleus'
    IA__INTERCALATED_AMYGDALA = 'IA - Intercalated amygdalar nucleus'
    MEA__MEDIAL_AMYGDALAR_NUC = 'MEA - Medial amygdalar nucleus'
    G_PE__GLOBUS_PALLIDUS_EXT = 'GPe - Globus pallidus external segment'
    G_PI__GLOBUS_PALLIDUS_INT = 'GPi - Globus pallidus internal segment'
    SI__SUBSTANTIA_INNOMINATA = 'SI - Substantia innominata'
    MA__MAGNOCELLULAR_NUCLEUS = 'MA - Magnocellular nucleus'
    MS__MEDIAL_SEPTAL_NUCLEUS = 'MS - Medial septal nucleus'
    NDB__DIAGONAL_BAND_NUCLEU = 'NDB - Diagonal band nucleus'
    TRS__TRIANGULAR_NUCLEUS_O = 'TRS - Triangular nucleus of septum'
    BST__BED_NUCLEI_OF_THE_ST = 'BST - Bed nuclei of the stria terminalis'
    VAL__VENTRAL_ANTERIOR_LAT = 'VAL - Ventral anterior-lateral complex of the thalamus'
    VM__VENTRAL_MEDIAL_NUCLEU = 'VM - Ventral medial nucleus of the thalamus'
    VPL__VENTRAL_POSTEROLATER = 'VPL - Ventral posterolateral nucleus of the thalamus'
    VP_LPC__VENTRAL_POSTEROLA = 'VPLpc - Ventral posterolateral nucleus of the thalamus parvicellular part'
    VPM__VENTRAL_POSTEROMEDIA = 'VPM - Ventral posteromedial nucleus of the thalamus'
    VVP_MPC__VENTRAL_POSTEROME = 'VPMpc - Ventral posteromedial nucleus of the thalamus parvicellular part'
    PO_T__POSTERIOR_TRIANGULA = 'PoT - Posterior triangular thalamic nucleus'
    SPF__SUBPARAFASCICULAR_NU = 'SPF - Subparafascicular nucleus'
    SPA__SUBPARAFASCICULAR_AR = 'SPA - Subparafascicular area'
    PP__PERIPEDUNCULAR_NUCLEU = 'PP - Peripeduncular nucleus'
    MG__MEDIAL_GENICULATE_COM = 'MG - Medial geniculate complex'
    L_GD__DORSAL_PART_OF_THE = 'LGd - Dorsal part of the lateral geniculate complex'
    LP__LATERAL_POSTERIOR_NUC = 'LP - Lateral posterior nucleus of the thalamus'
    PO__POSTERIOR_COMPLEX_OF = 'PO - Posterior complex of the thalamus'
    POL__POSTERIOR_LIMITING_N = 'POL - Posterior limiting nucleus of the thalamus'
    SGN__SUPRAGENICULATE_NUCL = 'SGN - Suprageniculate nucleus'
    ETH__ETHMOID_NUCLEUS_OF_T = 'Eth - Ethmoid nucleus of the thalamus'
    AV__ANTEROVENTRAL_NUCLEUS = 'AV - Anteroventral nucleus of thalamus'
    AM__ANTEROMEDIAL_NUCLEUS = 'AM - Anteromedial nucleus'
    AD__ANTERODORSAL_NUCLEUS = 'AD - Anterodorsal nucleus'
    IAM__INTERANTEROMEDIAL_NU = 'IAM - Interanteromedial nucleus of the thalamus'
    IAD__INTERANTERODORSAL_NU = 'IAD - Interanterodorsal nucleus of the thalamus'
    LD__LATERAL_DORSAL_NUCLEU = 'LD - Lateral dorsal nucleus of thalamus'
    IMD__INTERMEDIODORSAL_NUC = 'IMD - Intermediodorsal nucleus of the thalamus'
    MD__MEDIODORSAL_NUCLEUS_O = 'MD - Mediodorsal nucleus of thalamus'
    SMT__SUBMEDIAL_NUCLEUS_OF = 'SMT - Submedial nucleus of the thalamus'
    PR__PERIREUNENSIS_NUCLEUS = 'PR - Perireunensis nucleus'
    PVT__PARAVENTRICULAR_NUCL = 'PVT - Paraventricular nucleus of the thalamus'
    PT__PARATAENIAL_NUCLEUS = 'PT - Parataenial nucleus'
    RE__NUCLEUS_OF_REUNIENS = 'RE - Nucleus of reuniens'
    XI__XIPHOID_THALAMIC_NUCL = 'Xi - Xiphoid thalamic nucleus'
    RH__RHOMBOID_NUCLEUS = 'RH - Rhomboid nucleus'
    CM__CENTRAL_MEDIAL_NUCLEU = 'CM - Central medial nucleus of the thalamus'
    PCN__PARACENTRAL_NUCLEUS = 'PCN - Paracentral nucleus'
    CL__CENTRAL_LATERAL_NUCLE = 'CL - Central lateral nucleus of the thalamus'
    PF__PARAFASCICULAR_NUCLEU = 'PF - Parafascicular nucleus'
    PIL__POSTERIOR_INTRALAMIN = 'PIL - Posterior intralaminar thalamic nucleus'
    RT__RETICULAR_NUCLEUS_OF = 'RT - Reticular nucleus of the thalamus'
    IGL__INTERGENICULATE_LEAF = 'IGL - Intergeniculate leaflet of the lateral geniculate complex'
    INT_G__INTERMEDIATE_GENIC = 'IntG - Intermediate geniculate nucleus'
    L_GV__VENTRAL_PART_OF_THE = 'LGv - Ventral part of the lateral geniculate complex'
    SUB_G__SUBGENICULATE_NUCL = 'SubG - Subgeniculate nucleus'
    MH__MEDIAL_HABENULA = 'MH - Medial habenula'
    LH__LATERAL_HABENULA = 'LH - Lateral habenula'
    SO__SUPRAOPTIC_NUCLEUS = 'SO - Supraoptic nucleus'
    PVH__PARAVENTRICULAR_HYPO = 'PVH - Paraventricular hypothalamic nucleus'
    P_VA__PERIVENTRICULAR_HYP = 'PVa - Periventricular hypothalamic nucleus anterior part'
    P_VI__PERIVENTRICULAR_HYP = 'PVi - Periventricular hypothalamic nucleus intermediate part'
    ARH__ARCUATE_HYPOTHALAMIC = 'ARH - Arcuate hypothalamic nucleus'
    ADP__ANTERODORSAL_PREOPTI = 'ADP - Anterodorsal preoptic nucleus'
    AVP__ANTEROVENTRAL_PREOPT = 'AVP - Anteroventral preoptic nucleus'
    AVPV__ANTEROVENTRAL_PERIV = 'AVPV - Anteroventral periventricular nucleus'
    DMH__DORSOMEDIAL_NUCLEUS = 'DMH - Dorsomedial nucleus of the hypothalamus'
    MEPO__MEDIAN_PREOPTIC_NUC = 'MEPO - Median preoptic nucleus'
    MPO__MEDIAL_PREOPTIC_AREA = 'MPO - Medial preoptic area'
    PS__PARASTRIAL_NUCLEUS = 'PS - Parastrial nucleus'
    P_VP__PERIVENTRICULAR_HYP = 'PVp - Periventricular hypothalamic nucleus posterior part'
    P_VPO__PERIVENTRICULAR_HY = 'PVpo - Periventricular hypothalamic nucleus preoptic part'
    SBPV__SUBPARAVENTRICULAR = 'SBPV - Subparaventricular zone'
    SCH__SUPRACHIASMATIC_NUCL = 'SCH - Suprachiasmatic nucleus'
    SFO__SUBFORNICAL_ORGAN = 'SFO - Subfornical organ'
    VMPO__VENTROMEDIAL_PREOPT = 'VMPO - Ventromedial preoptic nucleus'
    VLPO__VENTROLATERAL_PREOP = 'VLPO - Ventrolateral preoptic nucleus'
    AHN__ANTERIOR_HYPOTHALAMI = 'AHN - Anterior hypothalamic nucleus'
    LM__LATERAL_MAMMILLARY_NU = 'LM - Lateral mammillary nucleus'
    MM__MEDIAL_MAMMILLARY_NUC = 'MM - Medial mammillary nucleus'
    SUM__SUPRAMAMMILLARY_NUCL = 'SUM - Supramammillary nucleus'
    TM__TUBEROMAMMILLARY_NUCL = 'TM - Tuberomammillary nucleus'
    MPN__MEDIAL_PREOPTIC_NUCL = 'MPN - Medial preoptic nucleus'
    P_MD__DORSAL_PREMAMMILLAR = 'PMd - Dorsal premammillary nucleus'
    P_MV__VENTRAL_PREMAMMILLA = 'PMv - Ventral premammillary nucleus'
    PV_HD__PARAVENTRICULAR_HY = 'PVHd - Paraventricular hypothalamic nucleus descending division'
    VMH__VENTROMEDIAL_HYPOTHA = 'VMH - Ventromedial hypothalamic nucleus'
    PH__POSTERIOR_HYPOTHALAMI = 'PH - Posterior hypothalamic nucleus'
    LHA__LATERAL_HYPOTHALAMIC = 'LHA - Lateral hypothalamic area'
    LPO__LATERAL_PREOPTIC_ARE = 'LPO - Lateral preoptic area'
    PSTN__PARASUBTHALAMIC_NUC = 'PSTN - Parasubthalamic nucleus'
    PE_F__PERIFORNICAL_NUCLEU = 'PeF - Perifornical nucleus'
    RCH__RETROCHIASMATIC_AREA = 'RCH - Retrochiasmatic area'
    STN__SUBTHALAMIC_NUCLEUS = 'STN - Subthalamic nucleus'
    TU__TUBERAL_NUCLEUS = 'TU - Tuberal nucleus'
    ZI__ZONA_INCERTA = 'ZI - Zona incerta'
    S_CS__SUPERIOR_COLLICULUS = 'SCs - Superior colliculus sensory related'
    IC__INFERIOR_COLLICULUS = 'IC - Inferior colliculus'
    NB__NUCLEUS_OF_THE_BRACHI = 'NB - Nucleus of the brachium of the inferior colliculus'
    SAG__NUCLEUS_SAGULUM = 'SAG - Nucleus sagulum'
    PBG__PARABIGEMINAL_NUCLEU = 'PBG - Parabigeminal nucleus'
    S_NR__SUBSTANTIA_NIGRA_RE = 'SNr - Substantia nigra reticular part'
    VTA__VENTRAL_TEGMENTAL_AR = 'VTA - Ventral tegmental area'
    PN__PARANIGRAL_NUCLEUS = 'PN - Paranigral nucleus'
    RR__MIDBRAIN_RETICULAR_NU = 'RR - Midbrain reticular nucleus retrorubral area'
    MRN__MIDBRAIN_RETICULAR_N = 'MRN - Midbrain reticular nucleus'
    S_CM__SUPERIOR_COLLICULUS = 'SCm - Superior colliculus motor related'
    PAG__PERIAQUEDUCTAL_GRAY = 'PAG - Periaqueductal gray'
    APN__ANTERIOR_PRETECTAL_N = 'APN - Anterior pretectal nucleus'
    MPT__MEDIAL_PRETECTAL_ARE = 'MPT - Medial pretectal area'
    NOT__NUCLEUS_OF_THE_OPTIC = 'NOT - Nucleus of the optic tract'
    NPC__NUCLEUS_OF_THE_POSTE = 'NPC - Nucleus of the posterior commissure'
    OP__OLIVARY_PRETECTAL_NUC = 'OP - Olivary pretectal nucleus'
    PPT__POSTERIOR_PRETECTAL = 'PPT - Posterior pretectal nucleus'
    RPF__RETROPARAFASCICULAR = 'RPF - Retroparafascicular nucleus'
    CUN__CUNEIFORM_NUCLEUS = 'CUN - Cuneiform nucleus'
    RN__RED_NUCLEUS = 'RN - Red nucleus'
    III__OCULOMOTOR_NUCLEUS = 'III - Oculomotor nucleus'
    MA3__MEDIAL_ACCESORY_OCUL = 'MA3 - Medial accesory oculomotor nucleus'
    EW__EDINGER__WESTPHAL_NUC = 'EW - Edinger-Westphal nucleus'
    IV__TROCHLEAR_NUCLEUS = 'IV - Trochlear nucleus'
    PA4__PARATROCHLEAR_NUCLEU = 'Pa4 - Paratrochlear nucleus'
    VTN__VENTRAL_TEGMENTAL_NU = 'VTN - Ventral tegmental nucleus'
    AT__ANTERIOR_TEGMENTAL_NU = 'AT - Anterior tegmental nucleus'
    LT__LATERAL_TERMINAL_NUCL = 'LT - Lateral terminal nucleus of the accessory optic tract'
    DT__DORSAL_TERMINAL_NUCLE = 'DT - Dorsal terminal nucleus of the accessory optic tract'
    MT__MEDIAL_TERMINAL_NUCLE = 'MT - Medial terminal nucleus of the accessory optic tract'
    S_NC__SUBSTANTIA_NIGRA_CO = 'SNc - Substantia nigra compact part'
    PPN__PEDUNCULOPONTINE_NUC = 'PPN - Pedunculopontine nucleus'
    IF__INTERFASCICULAR_NUCLE = 'IF - Interfascicular nucleus raphe'
    IPN__INTERPEDUNCULAR_NUCL = 'IPN - Interpeduncular nucleus'
    RL__ROSTRAL_LINEAR_NUCLEU = 'RL - Rostral linear nucleus raphe'
    CLI__CENTRAL_LINEAR_NUCLE = 'CLI - Central linear nucleus raphe'
    DR__DORSAL_NUCLEUS_RAPHE = 'DR - Dorsal nucleus raphe'
    NLL__NUCLEUS_OF_THE_LATER = 'NLL - Nucleus of the lateral lemniscus'
    PSV__PRINCIPAL_SENSORY_NU = 'PSV - Principal sensory nucleus of the trigeminal'
    PB__PARABRACHIAL_NUCLEUS = 'PB - Parabrachial nucleus'
    SOC__SUPERIOR_OLIVARY_COM = 'SOC - Superior olivary complex'
    B__BARRINGTON_S_NUCLEUS = 'B - Barrington\'s nucleus'
    DTN__DORSAL_TEGMENTAL_NUC = 'DTN - Dorsal tegmental nucleus'
    PD_TG__POSTERODORSAL_TEGM = 'PDTg - Posterodorsal tegmental nucleus'
    PCG__PONTINE_CENTRAL_GRAY = 'PCG - Pontine central gray'
    PG__PONTINE_GRAY = 'PG - Pontine gray'
    PR_NC__PONTINE_RETICULAR = 'PRNc - Pontine reticular nucleus caudal part'
    SG__SUPRAGENUAL_NUCLEUS = 'SG - Supragenual nucleus'
    SUT__SUPRATRIGEMINAL_NUCL = 'SUT - Supratrigeminal nucleus'
    TRN__TEGMENTAL_RETICULAR = 'TRN - Tegmental reticular nucleus'
    V__MOTOR_NUCLEUS_OF_TRIGE = 'V - Motor nucleus of trigeminal'
    P5__PERITRIGEMINAL_ZONE = 'P5 - Peritrigeminal zone'
    ACS5__ACCESSORY_TRIGEMINA = 'Acs5 - Accessory trigeminal nucleus'
    PC5__PARVICELLULAR_MOTOR = 'PC5 - Parvicellular motor 5 nucleus'
    I5__INTERTRIGEMINAL_NUCLE = 'I5 - Intertrigeminal nucleus'
    CS__SUPERIOR_CENTRAL_NUCL = 'CS - Superior central nucleus raphe'
    LC__LOCUS_CERULEUS = 'LC - Locus ceruleus'
    LDT__LATERODORSAL_TEGMENT = 'LDT - Laterodorsal tegmental nucleus'
    NI__NUCLEUS_INCERTUS = 'NI - Nucleus incertus'
    PR_NR__PONTINE_RETICULAR = 'PRNr - Pontine reticular nucleus'
    RPO__NUCLEUS_RAPHE_PONTIS = 'RPO - Nucleus raphe pontis'
    SLC__SUBCERULEUS_NUCLEUS = 'SLC - Subceruleus nucleus'
    SLD__SUBLATERODORSAL_NUCL = 'SLD - Sublaterodorsal nucleus'
    MY__MEDULLA = 'MY - Medulla'
    AP__AREA_POSTREMA = 'AP - Area postrema'
    DCO__DORSAL_COCHLEAR_NUCL = 'DCO - Dorsal cochlear nucleus'
    VCO__VENTRAL_COCHLEAR_NUC = 'VCO - Ventral cochlear nucleus'
    CU__CUNEATE_NUCLEUS = 'CU - Cuneate nucleus'
    GR__GRACILE_NUCLEUS = 'GR - Gracile nucleus'
    ECU__EXTERNAL_CUNEATE_NUC = 'ECU - External cuneate nucleus'
    NTB__NUCLEUS_OF_THE_TRAPE = 'NTB - Nucleus of the trapezoid body'
    NTS__NUCLEUS_OF_THE_SOLIT = 'NTS - Nucleus of the solitary tract'
    SPVC__SPINAL_NUCLEUS_OF_T = 'SPVC - Spinal nucleus of the trigeminal caudal part'
    SPVI__SPINAL_NUCLEUS_OF_T = 'SPVI - Spinal nucleus of the trigeminal interpolar part'
    SPVO__SPINAL_NUCLEUS_OF_T = 'SPVO - Spinal nucleus of the trigeminal oral part'
    PA5__PARATRIGEMINAL_NUCLE = 'Pa5 - Paratrigeminal nucleus'
    VI__ABDUCENS_NUCLEUS = 'VI - Abducens nucleus'
    VII__FACIAL_MOTOR_NUCLEUS = 'VII - Facial motor nucleus'
    AMB__NUCLEUS_AMBIGUUS = 'AMB - Nucleus ambiguus'
    DMX__DORSAL_MOTOR_NUCLEUS = 'DMX - Dorsal motor nucleus of the vagus nerve'
    GRN__GIGANTOCELLULAR_RETI = 'GRN - Gigantocellular reticular nucleus'
    ICB__INFRACEREBELLAR_NUCL = 'ICB - Infracerebellar nucleus'
    IO__INFERIOR_OLIVARY_COMP = 'IO - Inferior olivary complex'
    IRN__INTERMEDIATE_RETICUL = 'IRN - Intermediate reticular nucleus'
    ISN__INFERIOR_SALIVATORY = 'ISN - Inferior salivatory nucleus'
    LIN__LINEAR_NUCLEUS_OF_TH = 'LIN - Linear nucleus of the medulla'
    LRN__LATERAL_RETICULAR_NU = 'LRN - Lateral reticular nucleus'
    MARN__MAGNOCELLULAR_RETIC = 'MARN - Magnocellular reticular nucleus'
    MDRN__MEDULLARY_RETICULAR = 'MDRN - Medullary reticular nucleus'
    PARN__PARVICELLULAR_RETIC = 'PARN - Parvicellular reticular nucleus'
    PAS__PARASOLITARY_NUCLEUS = 'PAS - Parasolitary nucleus'
    PGRN__PARAGIGANTOCELLULAR = 'PGRN - Paragigantocellular reticular nucleus'
    NR__NUCLEUS_OF__ROLLER = 'NR - Nucleus of Roller'
    PRP__NUCLEUS_PREPOSITUS = 'PRP - Nucleus prepositus'
    PMR__PARAMEDIAN_RETICULAR = 'PMR - Paramedian reticular nucleus'
    PPY__PARAPYRAMIDAL_NUCLEU = 'PPY - Parapyramidal nucleus'
    LAV__LATERAL_VESTIBULAR_N = 'LAV - Lateral vestibular nucleus'
    MV__MEDIAL_VESTIBULAR_NUC = 'MV - Medial vestibular nucleus'
    SPIV__SPINAL_VESTIBULAR_N = 'SPIV - Spinal vestibular nucleus'
    SUV__SUPERIOR_VESTIBULAR = 'SUV - Superior vestibular nucleus'
    X__NUCLEUS_X = 'x - Nucleus x'
    XII__HYPOGLOSSAL_NUCLEUS = 'XII - Hypoglossal nucleus'
    Y__NUCLEUS_Y = 'y - Nucleus y'
    RM__NUCLEUS_RAPHE_MAGNUS = 'RM - Nucleus raphe magnus'
    RPA__NUCLEUS_RAPHE_PALLID = 'RPA - Nucleus raphe pallidus'
    RO__NUCLEUS_RAPHE_OBSCURU = 'RO - Nucleus raphe obscurus'
    LING__LINGULA_I = 'LING - Lingula (I)'
    CENT2__LOBULE_II = 'CENT2 - Lobule II'
    CENT3__LOBULE_III = 'CENT3 - Lobule III'
    CUL4_5__LOBULES_IV_V = 'CUL4 5 - Lobules IV-V'
    DEC__DECLIVE_VI = 'DEC - Declive (VI)'
    FOTU__FOLIUM_TUBER_VERMIS = 'FOTU - Folium-tuber vermis (VII)'
    PYR__PYRAMUS_VIII = 'PYR - Pyramus (VIII)'
    UVU__UVULA_IX = 'UVU - Uvula (IX)'
    NOD__NODULUS_X = 'NOD - Nodulus (X)'
    SIM__SIMPLE_LOBULE = 'SIM - Simple lobule'
    A_NCR1__CRUS_1 = 'ANcr1 - Crus 1'
    A_NCR2__CRUS_2 = 'ANcr2 - Crus 2'
    PRM__PARAMEDIAN_LOBULE = 'PRM - Paramedian lobule'
    COPY__COPULA_PYRAMIDIS = 'COPY - Copula pyramidis'
    PFL__PARAFLOCCULUS = 'PFL - Paraflocculus'
    FL__FLOCCULUS = 'FL - Flocculus'
    FN__FASTIGIAL_NUCLEUS = 'FN - Fastigial nucleus'
    IP__INTERPOSED_NUCLEUS = 'IP - Interposed nucleus'
    DN__DENTATE_NUCLEUS = 'DN - Dentate nucleus'
    VE_CB__VESTIBULOCEREBELLA = 'VeCB - Vestibulocerebellar nucleus'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of NSB2023Burr6IntendedCcfTarget from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from aind_sharepoint_service_async_client.models.nsb2019_list import NSB2019List

class TestNSB2019List(unittest.TestCase):
    """NSB2019List unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> NSB2019List:
        """Test NSB2019List
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `NSB2019List`
        """
        model = NSB2019List()
        if include_optional:
            return NSB2019List(
                age_x0020_at_x0020_injection = '',
                ap2nd_inj = '',
                author_id = 56,
                breg2_lamb = '',
                cage = '',
                color_tag = '',
                com_after1st_inj = 'Bleeding',
                com_after2nd_inj = 'Bleeding',
                com_coplanar = 'Mild',
                com_damage = 'Mild',
                com_during1st_inj = 'Bleeding',
                com_during2nd_inj = 'Bleeding',
                com_durotomy = 'Complete',
                com_sinusbleed = 'Mild',
                com_swelling = 'Mild',
                com_window = 'Anterior',
                compliance_asset_id = '',
                contusion = 'Mild',
                craniotomy_type = 'Frontal Window 3mm',
                created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                date1st_injection = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                date2nd_injection = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                date_x0020_of_x0020_birth = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                date_x0020_of_x0020_surgery = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                date_range_end = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                date_range_start = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                dv2nd_inj = '',
                editor_id = 56,
                end_x0020_of_x0020_week = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                exudate_x0020_severity = 'Mild',
                eye_x0020_affected = 'Both',
                eye_x0020_issue = 'Cloud/Possibly Blind',
                fiber_implant1 = True,
                fiber_implant1_dv = '',
                fiber_implant2 = True,
                fiber_implant2_dv = '',
                field30 = '',
                field50 = '',
                first_inj_recovery = 1.337,
                first_injection_iso_duration = '',
                first_injection_weight_after = '',
                first_injection_weight_befor = '',
                first_round_ionto_issue = 'N/A',
                headpost_type = 'AI Straight Headbar',
                hemisphere2nd_inj = 'Left',
                hp_x0020_a_x002f_p = '',
                hp_x0020_diameter = '',
                hp_durotomy = 'No',
                hp_x0020__x0026__x0020_inj = '',
                hp_iso_level = '0.25',
                hp_loc = 'Center',
                hp_x0020_m_x002f_l = '',
                hp_perf = 'Left',
                hp_prev_inject = 'No',
                hp_recovery = 1.337,
                x0031_hp_x0020_requestor_x0020_ = '',
                hp_requestor_comments_plaintext = '',
                hp_surgeon_comments = '',
                hp_work_station = 'Select...',
                iacuc_x0020_protocol_x0020__x002 = '2001',
                id = 56,
                implant_id_coverslip_type = 'Custom Implant (add details in comments section)',
                inj1_alternating_time = '',
                inj1_angle_v2 = '',
                inj1_current = '',
                inj1_lenghtof_time = '',
                inj1_round = 'NA',
                inj1_storage_location = '',
                inj1_type = 'Iontophoresis',
                inj1_virus_strain_rt = '',
                inj1_vol = '',
                inj1angle0 = '0 degrees',
                inj1volperdepth = '',
                inj2_alternating_time = '',
                inj2_angle_v2 = '',
                inj2_current = '',
                inj2_lenghtof_time = '',
                inj2_round = 'NA',
                inj2_storage_location = '',
                inj2_type = 'Iontophoresis',
                inj2_virus_strain_rt = '',
                inj2_vol = '',
                inj2angle0 = '0 degrees',
                inj2volperdepth = '',
                ionto_number_hpinj = 'Ionto #1',
                ionto_number_inj1 = 'Ionto #1',
                ionto_number_inj2 = 'Ionto #1',
                iso_x0020_on = 1.337,
                issue = 'Exudate',
                lab_tracks_x0020_group = '',
                lab_tracks_x0020_id = '',
                lab_tracks_x0020_requestor = '',
                lims_x0020_required = 'No',
                light_x0020_cycle = 'Normal (6am to 8pm)',
                lim_staskflow1 = 'AIND Ephys (Passive Behavior)',
                lims_x0020_link = '',
                lims_x0020_project_x0020_code = 'aind-discovery',
                long1st_round_inj_cmts = '',
                long2nd_rnd_inj_cmts = '',
                long_requestor_comments = '',
                long_surgeon_comments = '',
                ml2nd_inj = '',
                modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                nanoject_number_inj10 = 'N/A',
                nanoject_number_inj2 = 'N/A',
                nd_roung_injection_comments = '',
                pedigree_name = '',
                procedure = 'Custom',
                project_x0020_id_x0020__x0028_te = 'CAM-C506',
                ret_setting0 = 'Off',
                ret_setting1 = 'Off',
                round1_inj_isolevel = '0.25',
                round2_inj_isolevel = '0.25',
                scabbing = 'Mild',
                second_inj_recover = 1.337,
                second_injection_iso_duration = '',
                second_injection_weight_after = '',
                second_injection_weight_before = '',
                second_round_ionto_issue = 'N/A',
                sex = 'Female',
                st_round_injection_comments = '',
                start_x0020_of_x0020_week = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                surgery_status = 'Injection Pending',
                title = '',
                touch_x0020_up_x0020__x0020_comp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                touch_x0020_up_x0020_status = 'Complete',
                touch_x0020_up_x0020_weight_x002 = '',
                ui_version_string = '',
                virus_x0020_a_x002f_p = '',
                virus_x0020_d_x002f_v = '',
                virus_x0020_hemisphere = 'Left',
                virus_x0020_m_x002f_l = '',
                weight_x0020_after_x0020_surgery = '',
                weight_x0020_before_x0020_surger = '',
                work_station1st_injection = 'Select...',
                work_station2nd_injection = 'Select...'
            )
        else:
            return NSB2019List(
        )
        """

    def testNSB2019List(self):
        """Test NSB2019List"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class NSB2023Burr2SpinalLocation(str, Enum):
    """
    Enum class for Burr 2 Spinal Location.
    """

    """
    allowed enum values
    """
    SELECT = 'Select...'
    BETWEEN_C1_C2 = 'Between C1-C2'
    BETWEEN_C2_C3 = 'Between C2-C3'
    BETWEEN_C3_C4 = 'Between C3-C4'
    BETWEEN_C4_C5 = 'Between C4-C5'
    BETWEEN_C6_C7 = 'Between C6-C7'
    BETWEEN_C7_C8 = 'Between C7-C8'
    BETWEEN_C8_T1 = 'Between C8-T1'
    BETWEEN_T1_T2 = 'Between T1-T2'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of NSB2023Burr2SpinalLocation from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class NSB2023BehaviorAutotrainCurriculum(str, Enum):
    """
    Enum class for NSB2023Behavior Autotrain Curriculum.
    """

    """
    allowed enum values
    """
    COUPLED__BAITING = 'Coupled Baiting'
    UNCOUPLED__BAITING = 'Uncoupled Baiting'
    UNCOUPLED__WITHOUT__BAITI = 'Uncoupled Without Baiting'
    N_A = 'N/A'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of NSB2023BehaviorAutotrainCurriculum from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from aind_sharepoint_service_async_client.api.default_api import DefaultApi


class TestDefaultApi(unittest.IsolatedAsyncioTestCase):
    """DefaultApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = DefaultApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_get_las2020(self) -> None:
        """Test case for get_las2020

        Get Las 2020
        """
        pass

    async def test_get_nsb2019(self) -> None:
        """Test case for get_nsb2019

        Get Nsb 2019
        """
        pass

    async def test_get_nsb2023(self) -> None:
        """Test case for get_nsb2023

        Get Nsb 2023
        """
        pass

    async def test_get_nsb_present(self) -> None:
        """Test case for get_nsb_present

        Get Nsb Present
        """
        pass


if __name__ == '__main__':
    unittest.main()
